#############################################################
#
# Ref to the ARTICLE
# 
# Davide Bulgarelli
# d.bulgarelli@dundee.ac.uk
# 01/12/2014
# script to reproduce figure 1 and associated statistical analyses
# files needed are comprised as individual worksheets in the Database S1
#"371A_530A_design.txt"  worksheet Design_Barley
#"dat_info_Barley_OTUPARSE_NM_sorted_L2.txt" worksheet Barley_phyla
#"dat_info_Barley_OTUPARSE_NM_sorted_L5.txt" worksheet Barley_familes
#
#############################################################


rm(list=ls())

#############################################################
# Libraries and functions required
#############################################################

library("limma")
library("marray")
library("BiocGenerics")
library("Biobase")
library("gplots")
library("sciplot")
library("Hmisc")
library("vegan")
library("Formula")
library("multcomp")
source("file2Exprs.R")
source("tern_e.R")

#############################################################



#set working directory
setwd("C:/Users/DB42008/ownCloud/Manuscripts/Barley_Microbiota_revisionCHM0814_scripts/Bulgarelli_et_al_figures_1-3-4-S1_R_scripts/")


# upload the design file
design <- read.delim("371A_530A_design.txt", sep = "\t", header=TRUE )
rownames(design) <- design[,1]
dim(design)
design

#data count and transformation
##############################
#Phylum (Figure 1A)
##############################
dat_info_taxa_Phylum<- read.delim ("dat_info_Barley_OTUPARSE_NM_sorted_L2.txt", sep = "\t", row.names=1, header=T, blank.lines.skip = FALSE)
colnames(dat_info_taxa_Phylum)
rownames(dat_info_taxa_Phylum)
dim(dat_info_taxa_Phylum)
dat_info_taxa_Phylum[1:5, 1:5]
dat_count_taxa_Phylum <- dat_info_taxa_Phylum
dat_norm_Phylum <- ((dat_count_taxa_Phylum)/colSums(dat_count_taxa_Phylum,na=T)) * 1000 

#create vectors for the description
genotypeSoil <- c("Bulk10", "Bulk11", "Bulk12", "Bulk20", "Bulk22", "Bulk23")
genotypeRhizosphere_spontaneum <- c("HIDRhizo10", "HIDRhizo11", "HIDRhizo12", "HIDRhizo20", "HIDRhizo21", "HIDRhizo22")
genotypeRhizosphere_landrace <- c("RumRhizo10", "RumRhizo11", "RumRhizo12", "RumRhizo20", "RumRhizo21", "RumRhizo22")
genotypeRhizosphere_modern<- c("MorexRhizo10", "MorexRhizo11", "MorexRhizo12", "MorexRhizo20", "MorexRhizo22", "MorexRhizo23")
genotypeRoot_spontaneum <- c("HIDRoot10", "HIDRoot11", "HIDRoot12", "HIDRoot20", "HIDRoot21", "HIDRoot22")
genotypeRoot_landrace <- c("RumRoot10", "RumRoot11", "RumRoot12", "RumRoot20", "RumRoot21", "RumRoot22")
genotypeRoot_modern<- c("MorexRoot10", "MorexRoot11", "MorexRoot12", "MorexRoot20", "MorexRoot22", "MorexRoot23")

#extract the mean information
genotypeRhizosphere_Phylum_spontaneum_mean <- as.data.frame(rowMeans(dat_norm_Phylum[, genotypeRhizosphere_spontaneum]))
genotypeRhizosphere_Phylum_landrace_mean <- as.data.frame(rowMeans(dat_norm_Phylum[, genotypeRhizosphere_landrace]))
genotypeRhizosphere_Phylum_modern_mean <- as.data.frame(rowMeans(dat_norm_Phylum[, genotypeRhizosphere_modern]))
genotypeRoot_Phylum_spontaneum_mean <- as.data.frame(rowMeans(dat_norm_Phylum[, genotypeRoot_spontaneum]))
genotypeRoot_Phylum_landrace_mean <- as.data.frame(rowMeans(dat_norm_Phylum[, genotypeRoot_landrace]))
genotypeRoot_Phylum_modern_mean <- as.data.frame(rowMeans(dat_norm_Phylum[, genotypeRoot_modern]))
genotypeSoil_Phylum_mean <- as.data.frame(rowMeans(dat_norm_Phylum[, genotypeSoil]))

#compute the Standard errors
std <- function(x) sd(x)/sqrt(length(x))
genotypeRhizosphere_Phylum_spontaneum_STD <- as.data.frame(apply((dat_norm_Phylum[, genotypeRhizosphere_spontaneum]), 1, std))
genotypeRhizosphere_Phylum_landrace_STD <- as.data.frame(apply((dat_norm_Phylum[, genotypeRhizosphere_landrace]), 1, std))
genotypeRhizosphere_Phylum_modern_STD <- as.data.frame(apply((dat_norm_Phylum[, genotypeRhizosphere_modern]), 1, std))
genotypeRoot_Phylum_spontaneum_STD <- as.data.frame(apply((dat_norm_Phylum[, genotypeRoot_spontaneum]), 1, std))
genotypeRoot_Phylum_landrace_STD <- as.data.frame(apply((dat_norm_Phylum[, genotypeRoot_landrace]), 1, std))
genotypeRoot_Phylum_modern_STD <-  as.data.frame(apply((dat_norm_Phylum[, genotypeRoot_modern]), 1, std))
genotypeSoil_Phylum_STD <- as.data.frame(apply((dat_norm_Phylum[, genotypeSoil]), 1, std))

#create the graphical output for the soil
sample_soils <- genotypeSoil_Phylum_mean 

#create the data matrices for plotting
#Rhizosphere
count_Phylum <- cbind(genotypeSoil_Phylum_mean, genotypeRhizosphere_Phylum_spontaneum_mean, genotypeRoot_Phylum_spontaneum_mean, genotypeRhizosphere_Phylum_landrace_mean, genotypeRoot_Phylum_landrace_mean, genotypeRhizosphere_Phylum_modern_mean, genotypeRoot_Phylum_modern_mean)
colnames(count_Phylum) <- c("Soil", "Spontaneum Rhizo", "Spontaneum Root", "Landrace Rhizo", "Landrace Root", "Modern Rhizo", "Modern Root")
topRank <- c("k__Bacteria;p__Proteobacteria", "k__Bacteria;p__Actinobacteria", "k__Bacteria;p__Bacteroidetes", "k__Bacteria;p__Firmicutes", "k__Bacteria;p__Chloroflexi")
topRank
count_Phylum_topRank <- count_Phylum[topRank, ]
count_Phylum_topRank <- as.matrix(count_Phylum_topRank)
count_Phylum_STD <- cbind(genotypeSoil_Phylum_STD, genotypeRhizosphere_Phylum_spontaneum_STD, genotypeRoot_Phylum_spontaneum_STD, genotypeRhizosphere_Phylum_landrace_STD, genotypeRoot_Phylum_landrace_STD, genotypeRhizosphere_Phylum_modern_STD, genotypeRoot_Phylum_modern_STD)
colnames(count_Phylum_STD) <- c("Soil", "Spontaneum Rhizo", "Spontaneum Root", "Landrace Rhizo", "Landrace Root", "Modern Rhizo", "Modern Root")
count_Phylum_STD_topRank <- count_Phylum_STD[topRank, ]
count_Phylum_STD_topRank <- as.matrix(count_Phylum_STD_topRank)

#rename the rownames in the matrices
rownames(count_Phylum_topRank) <- c("Proteobacteria", "Actinobacteria", "Bacteroidetes", "Firmicutes", "Chloroflexi")
                                    

#rename the rownames in the matrices
rownames(count_Phylum_STD_topRank) <- c("Proteobacteria", "Actinobacteria", "Bacteroidetes", "Firmicutes", "Chloroflexi")

#calculate the RA of Actinobacteria, Bacteroidetes and Proteobacteria in these two compartments
top_phyla_RA_rhizo <- median(colSums(count_Phylum_topRank[c("Proteobacteria", "Actinobacteria", "Bacteroidetes"), c("Spontaneum Rhizo", "Landrace Rhizo", "Modern Rhizo")]))
top_phyla_RA_root <- median(colSums(count_Phylum_topRank[c("Proteobacteria", "Actinobacteria", "Bacteroidetes"), c("Spontaneum Root", "Landrace Root", "Modern Root")]))

#plotting error bars
#function error bar from http://stackoverflow.com/questions/2381618/how-to-draw-a-chart-with-sorted-horizontal-error-bars-sorted-barcharts-with-err
#note the modification upper bar only and adjustable depending on the number of the samples
#this function enables to combine a data matrix with defined mean with another containing the error information: DOES NOT CALCULATE any dispersion index the user has to provide this piece of information
error.barsDB <- function(x,y,z){
  g <- (max(y)-min(y))/(3*length(y))
  for (i in 1:length(y)){lines(c(x[i]+z[i],x[i]-0),c(y[i],y[i]))
                         lines(c(x[i]+z[i],x[i]+z[i]),c(y[i]+g,y[i]-g))
                         
  }}


#plotting
dev.off()
par(mfrow=c(2,1))
bar_count_Phylum <- barplot(t(count_Phylum_topRank), horiz=TRUE, beside=TRUE ,col=c("white","mediumblue", "mediumblue", "darkgreen", "darkgreen", "darkred", "darkred"),  ylab="Phyla", axis.lty=1, xlim = c(0,800), main="Phyla distribution")
error.barsDB(t(count_Phylum_topRank), bar_count_Phylum, t(count_Phylum_STD_topRank))
legend("topright", c("Bulk Soil", "Hordeum vulgare ssp. spontaneum","Hordeum vulgare ssp. vulgare Landrace", "Hordeum vulgare ssp. vulgare Modern"), cex=1, 
       bty="n", fill=c("white","mediumblue", "darkgreen","darkred"))

##############################
#Family (Figure 1B)
##############################

dat_info_taxa_Family<- read.delim ("dat_info_Barley_OTUPARSE_NM_sorted_L5.txt", sep = "\t", row.names=1, header=T, blank.lines.skip = FALSE)
colnames(dat_info_taxa_Family)
rownames(dat_info_taxa_Family)
dim(dat_info_taxa_Family)
dat_info_taxa_Family[1:5, 1:5]
dat_count_taxa_Family <- dat_info_taxa_Family
dat_norm_Family <- t(t(dat_count_taxa_Family)/colSums(dat_count_taxa_Family,na=T)) * 1000

#extract the mean information
genotypeRhizosphere_Family_spontaneum_mean <- as.data.frame(rowMeans(dat_norm_Family[, genotypeRhizosphere_spontaneum]))
genotypeRhizosphere_Family_landrace_mean <- as.data.frame(rowMeans(dat_norm_Family[, genotypeRhizosphere_landrace]))
genotypeRhizosphere_Family_modern_mean <- as.data.frame(rowMeans(dat_norm_Family[, genotypeRhizosphere_modern]))
genotypeRoot_Family_spontaneum_mean <- as.data.frame(rowMeans(dat_norm_Family[, genotypeRoot_spontaneum]))
genotypeRoot_Family_landrace_mean <- as.data.frame(rowMeans(dat_norm_Family[, genotypeRoot_landrace]))
genotypeRoot_Family_modern_mean <- as.data.frame(rowMeans(dat_norm_Family[, genotypeRoot_modern]))
genotypeSoil_Family_mean <- as.data.frame(rowMeans(dat_norm_Family[, genotypeSoil]))

#compute the Standard errors
std <- function(x) sd(x)/sqrt(length(x))
genotypeRhizosphere_Family_spontaneum_STD <- as.data.frame(apply((dat_norm_Family[, genotypeRhizosphere_spontaneum]), 1, std))
genotypeRhizosphere_Family_landrace_STD <- as.data.frame(apply((dat_norm_Family[, genotypeRhizosphere_landrace]), 1, std))
genotypeRhizosphere_Family_modern_STD <- as.data.frame(apply((dat_norm_Family[, genotypeRhizosphere_modern]), 1, std))
genotypeRoot_Family_spontaneum_STD <- as.data.frame(apply((dat_norm_Family[, genotypeRoot_spontaneum]), 1, std))
genotypeRoot_Family_landrace_STD <- as.data.frame(apply((dat_norm_Family[, genotypeRoot_landrace]), 1, std))
genotypeRoot_Family_modern_STD <-  as.data.frame(apply((dat_norm_Family[, genotypeRoot_modern]), 1, std))
genotypeSoil_Family_STD <- as.data.frame(apply((dat_norm_Family[, genotypeSoil]), 1, std))

#create the graphical output for the soil
sample_soils <- genotypeSoil_Family_mean 

#create the data matrices for plotting
count_Family <- cbind(genotypeSoil_Family_mean, genotypeRhizosphere_Family_spontaneum_mean, genotypeRoot_Family_spontaneum_mean, genotypeRhizosphere_Family_landrace_mean, genotypeRoot_Family_landrace_mean, genotypeRhizosphere_Family_modern_mean, genotypeRoot_Family_modern_mean)
colnames(count_Family) <- c("Soil", "Spontaneum Rhizo", "Spontaneum Root", "Landrace Rhizo", "Landrace Root", "Modern Rhizo", "Modern Root")

#sort by cumulative relative abundance across the plant-associated samples and identify dominant family
Family_mean_plant <- cbind(genotypeRhizosphere_Family_spontaneum_mean, genotypeRhizosphere_Family_landrace_mean , genotypeRhizosphere_Family_modern_mean, genotypeRoot_Family_spontaneum_mean, genotypeRoot_Family_landrace_mean , genotypeRoot_Family_modern_mean)
colnames(Family_mean_plant) <- c("Spontaneum_Rhizo", "Landrace_Rhizo", "Modern_Rhizo", "Spontaneum_Root", "Landrace_Root", "Modern_Root")
Family_mean_plant_sorted <- Family_mean_plant[(order(-rowSums(Family_mean_plant))), ] 
Family_mean_plant_topRank <- Family_mean_plant_sorted[1:5, ]
Family_mean_plant_topRank 

#generate the matrices for plotting
count_Family_topRank <- count_Family[rownames(Family_mean_plant_topRank), ]
count_Family_topRank <- as.matrix(count_Family_topRank)
count_Family_STD <- cbind(genotypeSoil_Family_STD, genotypeRhizosphere_Family_spontaneum_STD, genotypeRoot_Family_spontaneum_STD, genotypeRhizosphere_Family_landrace_STD, genotypeRoot_Family_landrace_STD, genotypeRhizosphere_Family_modern_STD, genotypeRoot_Family_modern_STD)
colnames(count_Family_STD) <- c("Soil", "Spontaneum Rhizo", "Spontaneum Root", "Landrace Rhizo", "Landrace Root", "Modern Rhizo", "Modern Root")
count_Family_STD_topRank <- count_Family_STD[rownames(Family_mean_plant_topRank), ]
count_Family_STD_topRank <- as.matrix(count_Family_STD_topRank)

#rename the rownames in the matrices
rownames(count_Family_topRank) <- c("Flavobacteriaceae", "Oxalobacteraceae", "Comamonadaceae", "Rhizobiaceae", "Streptomycetaceae")


#rename the rownames in the matrices
rownames(count_Family_STD_topRank) <- c("Flavobacteriaceae", "Oxalobacteraceae", "Comamonadaceae", "Rhizobiaceae", "Streptomycetaceae")



#plotting
bar_count_Family <- barplot(t(count_Family_topRank), horiz=TRUE, beside=TRUE ,col=c("white","mediumblue", "mediumblue", "darkgreen", "darkgreen", "darkred", "darkred"),  ylab="Families", axis.lty=1, xlim = c(0,350), main="Families distribution")
error.barsDB(t(count_Family_topRank), bar_count_Family, t(count_Family_STD_topRank))

#Picture saved as .eps and edited in Adobe Illustrator (note that the second bar of each taxon*genotype represents rhizosphere counts)

#Statistical analysis
##############################
#Phylum (Figure 1A)
##############################

# upload the design file
design <- read.delim("371A_530A_design.txt", sep = "\t", header=TRUE )
rownames(design) <- design[,1]
dim(design)
design

dat_info_taxa_phylum <- read.delim ("dat_info_Barley_OTUPARSE_NM_sorted_L2.txt", sep = "\t", row.names=1, header=T, blank.lines.skip = FALSE)
colnames(dat_info_taxa_phylum)
rownames(design)
rownames(dat_info_taxa_phylum)
dim(dat_info_taxa_phylum)
dat_info_taxa_phylum[1:5, 1:5]
dat_count_taxa_phylum<- dat_info_taxa_phylum
dat_norm_phylum <- ((dat_count_taxa_phylum)/colSums(dat_count_taxa_phylum,na=T)) * 1000 

#preprocessing of the data (threshold and log transformation)
# threshold
# 0.5% presence: use integer 5 considering x1000 normalization
threshold <- 5
# normalization by sample size and transformation in "/1000"
dat_norm <- t(t(dat_count_taxa_phylum)/colSums(dat_count_taxa_phylum,na=T)) * 1000 
# application of threshold for lower presence limit of relative abundance
dat_thres <- dat_norm[ apply(dat_norm,1,max) > threshold, ]
# log2-transformation
dat_log <- log2(dat_thres + 1)
dim(dat_log)
dat_log[1:10,1:5]
# preparation of eset format
eset <- new("ExpressionSet")
exprs(eset) <- dat_log
pData(eset) <- design

#define the factor Microhabitat corrected for Accession
genotype <- as.vector(paste(design$Microhabitat, design$Accession, sep="."))
model_genotype <- model.matrix(~0 + genotype)
colnames(model_genotype) <- make.names(colnames(model_genotype))
colnames(model_genotype)
#fit the linear model
fit_genotype <- lmFit(eset, model_genotype)
#Microhabitat * Accession effect
cont.matrix_genotype <- makeContrasts(
  Soil_vs_Root_modern = genotypeSoil.Golm - genotypeRoot.modern,
  Soil_vs_Root_landrace = genotypeSoil.Golm - genotypeRoot.landrace,
  Soil_vs_Root_spontaneum = genotypeSoil.Golm - genotypeRoot.spontaneum,
  Soil_vs_Rhizosphere_modern = genotypeSoil.Golm - genotypeRhizosphere.modern,
  Soil_vs_Rhizosphere_landrace = genotypeSoil.Golm - genotypeRhizosphere.landrace,
  Soil_vs_Rhizosphere_spontaneum = genotypeSoil.Golm - genotypeRhizosphere.spontaneum,
  Root_vs_Rhizosphere_modern = genotypeRoot.modern - genotypeRhizosphere.modern,
  Root_vs_Rhizosphere_landrace = genotypeRoot.landrace - genotypeRhizosphere.landrace,
  Root_vs_Rhizosphere_spontaneum = genotypeRoot.spontaneum - genotypeRhizosphere.spontaneum,
  Root_modern_vs_spontaneum = genotypeRoot.modern - genotypeRoot.spontaneum,
  Root_landrace_vs_spontaneum = genotypeRoot.landrace - genotypeRoot.spontaneum,
  Root_modern_vs_landrace = genotypeRoot.modern - genotypeRoot.landrace,
  Rhizosphere_modern_vs_spontaneum = genotypeRhizosphere.modern - genotypeRhizosphere.spontaneum,
  Rhizosphere_landrace_vs_spontaneum = genotypeRhizosphere.landrace - genotypeRhizosphere.spontaneum,
  Rhizosphere_modern_vs_landrace = genotypeRhizosphere.modern - genotypeRhizosphere.landrace,
  levels = model_genotype)
# Compute estimated coefficients and standard errors for the given contrasts
fit2_genotype <- contrasts.fit(fit_genotype, cont.matrix_genotype)
fit2_genotype <- eBayes(fit2_genotype)
#decideTests: by default lfc>0, BH correct
de_tab_genotype <- decideTests(fit2_genotype)

#Root effect: enriched from soil
Root_modern_phyla <- rownames(de_tab_genotype)[de_tab_genotype[,1] ==-1]
Root_landrace_phyla <- rownames(de_tab_genotype)[de_tab_genotype[,2] ==-1]
Root_spontaneum_phyla <- rownames(de_tab_genotype)[de_tab_genotype[,3] ==-1]
length(Root_modern_phyla)
length(Root_landrace_phyla)
length(Root_spontaneum_phyla)
Root_modern_phyla
Root_landrace_phyla
Root_spontaneum_phyla

#Rhizosphere effect: enriched from soil
Rhizo_modern_phyla <- rownames(de_tab_genotype)[de_tab_genotype[,4] ==-1]
Rhizo_landrace_phyla <- rownames(de_tab_genotype)[de_tab_genotype[,5] ==-1]
Rhizo_spontaneum_phyla <- rownames(de_tab_genotype)[de_tab_genotype[,6] ==-1]
length(Rhizo_modern_phyla)
length(Rhizo_landrace_phyla)
length(Rhizo_spontaneum_phyla)
Rhizo_modern_phyla
Rhizo_landrace_phyla
Rhizo_spontaneum_phyla

#########################################################
#Genotype effect corrected for Microhabitat and experiment
#########################################################

genotype <- as.vector(paste(design$Microhabitat, design$Experiment, design$Accession, sep="."))
model_genotype <- model.matrix(~0 + genotype)
colnames(model_genotype) <- make.names(colnames(model_genotype))
colnames(model_genotype)
#fit the linear model
fit_genotype <- lmFit(eset, model_genotype)
#Genotype effect Rhizosphere 
cont.matrix_genotype <- makeContrasts(
  M_vs_L_3 = genotypeRhizosphere.Barley3.modern - genotypeRhizosphere.Barley3.landrace,
  M_vs_L_2 = genotypeRhizosphere.Barley2.modern - genotypeRhizosphere.Barley2.landrace,
  M_vs_S_3 = genotypeRhizosphere.Barley3.modern - genotypeRhizosphere.Barley3.spontaneum,
  M_vs_S_2 = genotypeRhizosphere.Barley2.modern - genotypeRhizosphere.Barley2.spontaneum,
  S_vs_L_3 = genotypeRhizosphere.Barley3.spontaneum - genotypeRhizosphere.Barley3.landrace,
  S_vs_L_2 = genotypeRhizosphere.Barley2.spontaneum - genotypeRhizosphere.Barley2.landrace,
  levels = model_genotype)
# Compute estimated coefficients and standard errors for the given contrasts
fit2_genotype <- contrasts.fit(fit_genotype, cont.matrix_genotype)
fit2_genotype <- eBayes(fit2_genotype)

#decideTests: by default lfc=>0, BH corrected
de_tab_genotype <- decideTests(fit2_genotype)

#identify relevant phyla
M_vs_L_3_phyla_1193_Rhizo <- rownames(de_tab_genotype)[de_tab_genotype[,1] ==1]
L_vs_M_3_phyla_1193_Rhizo <- rownames(de_tab_genotype)[de_tab_genotype[,1] == -1]
M_vs_L_2_phyla_1193_Rhizo <- rownames(de_tab_genotype)[de_tab_genotype[,2] ==1]
L_vs_M_2_phyla_1193_Rhizo <- rownames(de_tab_genotype)[de_tab_genotype[,2] == -1]
M_vs_S_3_phyla_1193_Rhizo <- rownames(de_tab_genotype)[de_tab_genotype[,3] ==1]
S_vs_M_3_phyla_1193_Rhizo <- rownames(de_tab_genotype)[de_tab_genotype[,3] == -1]
M_vs_S_2_phyla_1193_Rhizo <- rownames(de_tab_genotype)[de_tab_genotype[,4] ==1]
S_vs_M_2_phyla_1193_Rhizo <- rownames(de_tab_genotype)[de_tab_genotype[,4] == -1]
S_vs_L_3_phyla_1193_Rhizo <- rownames(de_tab_genotype)[de_tab_genotype[,5] == 1]
L_vs_S_3_phyla_1193_Rhizo <- rownames(de_tab_genotype)[de_tab_genotype[,5] == -1]
S_vs_L_2_phyla_1193_Rhizo <- rownames(de_tab_genotype)[de_tab_genotype[,6] == 1]
L_vs_S_2_phyla_1193_Rhizo <- rownames(de_tab_genotype)[de_tab_genotype[,6] == -1]
length(M_vs_L_3_phyla_1193_Rhizo)
length(L_vs_M_3_phyla_1193_Rhizo)
length(M_vs_L_2_phyla_1193_Rhizo)
length(L_vs_M_2_phyla_1193_Rhizo)
length(M_vs_S_3_phyla_1193_Rhizo)
length(S_vs_M_3_phyla_1193_Rhizo)
length(M_vs_S_2_phyla_1193_Rhizo)
length(S_vs_M_2_phyla_1193_Rhizo)
length(L_vs_S_3_phyla_1193_Rhizo)
length(L_vs_S_2_phyla_1193_Rhizo)
length(S_vs_L_3_phyla_1193_Rhizo)
length(S_vs_L_2_phyla_1193_Rhizo)
M_vs_L_Rhizo_phyla_1193 <- intersect (M_vs_L_3_phyla_1193_Rhizo, M_vs_L_2_phyla_1193_Rhizo)
M_vs_S_Rhizo_phyla_1193 <- intersect (M_vs_S_3_phyla_1193_Rhizo, M_vs_S_2_phyla_1193_Rhizo)
L_vs_M_Rhizo_phyla_1193 <- intersect (L_vs_M_3_phyla_1193_Rhizo, L_vs_M_2_phyla_1193_Rhizo)
L_vs_S_Rhizo_phyla_1193 <- intersect (L_vs_S_3_phyla_1193_Rhizo, L_vs_S_2_phyla_1193_Rhizo)
S_vs_M_Rhizo_phyla_1193 <- intersect (S_vs_M_3_phyla_1193_Rhizo, S_vs_M_2_phyla_1193_Rhizo)
S_vs_L_Rhizo_phyla_1193 <- intersect (S_vs_L_3_phyla_1193_Rhizo, S_vs_L_2_phyla_1193_Rhizo)
length(M_vs_L_Rhizo_phyla_1193)
length(M_vs_S_Rhizo_phyla_1193)
length(L_vs_M_Rhizo_phyla_1193)
length(L_vs_S_Rhizo_phyla_1193)
length(S_vs_M_Rhizo_phyla_1193)
length(S_vs_L_Rhizo_phyla_1193)

#Genotype effect root 
cont.matrix_genotype <- makeContrasts(
  M_vs_L_3 = genotypeRoot.Barley3.modern - genotypeRoot.Barley3.landrace,
  M_vs_L_2 = genotypeRoot.Barley2.modern - genotypeRoot.Barley2.landrace,
  M_vs_S_3 = genotypeRoot.Barley3.modern - genotypeRoot.Barley3.spontaneum,
  M_vs_S_2 = genotypeRoot.Barley2.modern - genotypeRoot.Barley2.spontaneum,
  S_vs_L_3 = genotypeRoot.Barley3.spontaneum - genotypeRoot.Barley3.landrace,
  S_vs_L_2 = genotypeRoot.Barley2.spontaneum - genotypeRoot.Barley2.landrace,
  levels = model_genotype)
# Compute estimated coefficients and standard errors for the given contrasts
fit2_genotype <- contrasts.fit(fit_genotype, cont.matrix_genotype)
fit2_genotype <- eBayes(fit2_genotype)
#decideTests: by default lfc>0, BH correct
de_tab_genotype <- decideTests(fit2_genotype)
#identify relevant phyla
M_vs_L_3_phyla_1193_Root <- rownames(de_tab_genotype)[de_tab_genotype[,1] ==1]
L_vs_M_3_phyla_1193_Root <- rownames(de_tab_genotype)[de_tab_genotype[,1] == -1]
M_vs_L_2_phyla_1193_Root <- rownames(de_tab_genotype)[de_tab_genotype[,2] ==1]
L_vs_M_2_phyla_1193_Root <- rownames(de_tab_genotype)[de_tab_genotype[,2] == -1]
M_vs_S_3_phyla_1193_Root <- rownames(de_tab_genotype)[de_tab_genotype[,3] ==1]
S_vs_M_3_phyla_1193_Root <- rownames(de_tab_genotype)[de_tab_genotype[,3] == -1]
M_vs_S_2_phyla_1193_Root <- rownames(de_tab_genotype)[de_tab_genotype[,4] ==1]
S_vs_M_2_phyla_1193_Root <- rownames(de_tab_genotype)[de_tab_genotype[,4] == -1]
S_vs_L_3_phyla_1193_Root <- rownames(de_tab_genotype)[de_tab_genotype[,5] == 1]
L_vs_S_3_phyla_1193_Root <- rownames(de_tab_genotype)[de_tab_genotype[,5] == -1]
S_vs_L_2_phyla_1193_Root <- rownames(de_tab_genotype)[de_tab_genotype[,6] == 1]
L_vs_S_2_phyla_1193_Root <- rownames(de_tab_genotype)[de_tab_genotype[,6] == -1]
length(M_vs_L_3_phyla_1193_Root)
length(L_vs_M_3_phyla_1193_Root)
length(M_vs_L_2_phyla_1193_Root)
length(L_vs_M_2_phyla_1193_Root)
length(M_vs_S_3_phyla_1193_Root)
length(S_vs_M_3_phyla_1193_Root)
length(M_vs_S_2_phyla_1193_Root)
length(S_vs_M_2_phyla_1193_Root)
length(L_vs_S_3_phyla_1193_Root)
length(L_vs_S_2_phyla_1193_Root)
M_vs_L_Root_phyla_1193 <- intersect (M_vs_L_3_phyla_1193_Root, M_vs_L_2_phyla_1193_Root)
M_vs_S_Root_phyla_1193 <- intersect (M_vs_S_3_phyla_1193_Root, M_vs_S_2_phyla_1193_Root)
L_vs_M_Root_phyla_1193 <- intersect (L_vs_M_3_phyla_1193_Root, L_vs_M_2_phyla_1193_Root)
L_vs_S_Root_phyla_1193 <- intersect (L_vs_S_3_phyla_1193_Root, L_vs_S_2_phyla_1193_Root)
S_vs_M_Root_phyla_1193 <- intersect (S_vs_M_3_phyla_1193_Root, S_vs_M_2_phyla_1193_Root)
S_vs_L_Root_phyla_1193 <- intersect (S_vs_L_3_phyla_1193_Root, S_vs_L_2_phyla_1193_Root)
length(M_vs_L_Root_phyla_1193)
length(M_vs_S_Root_phyla_1193)
length(L_vs_M_Root_phyla_1193)
length(L_vs_S_Root_phyla_1193)
length(S_vs_M_Root_phyla_1193)
length(S_vs_L_Root_phyla_1193)


#Statistical analysis
##############################
#Family (Figure 1B)
##############################
dat_info_taxa_family <- read.delim ("dat_info_Barley_OTUPARSE_NM_sorted_L5.txt", sep = "\t", row.names=1, header=T, blank.lines.skip = FALSE)
colnames(dat_info_taxa_family)
rownames(dat_info_taxa_family)
dim(dat_info_taxa_family)
dat_info_taxa_family[1:5, 1:5]
dat_count_taxa_family<- dat_info_taxa_family
dat_norm_family <- ((dat_count_taxa_family)/colSums(dat_count_taxa_family,na=T)) * 1000 

#preprocessing of the data (threshold and log transformation)
# threshold
# 0.5% presence: use integer 5 considering x1000 normalization
threshold <- 5
# normalization by sample size and transformation in "/1000"
dat_norm <- t(t(dat_count_taxa_family)/colSums(dat_count_taxa_family,na=T)) * 1000 
# application of threshold for lower presence limit of relative abundance
dat_thres <- dat_norm[ apply(dat_norm,1,max) > threshold, ]
# log2-transformation
dat_log <- log2(dat_thres + 1)
dim(dat_log)
dat_log[1:10,1:5]
# preparation of eset format
eset <- new("ExpressionSet")
exprs(eset) <- dat_log
pData(eset) <- design

#define the factor Microhabitat corrected for Accession
genotype <- as.vector(paste(design$Microhabitat, design$Accession, sep="."))
model_genotype <- model.matrix(~0 + genotype)
colnames(model_genotype) <- make.names(colnames(model_genotype))
colnames(model_genotype)
#fit the linear model
fit_genotype <- lmFit(eset, model_genotype)
#Microhabitat * Accession effect
cont.matrix_genotype <- makeContrasts(
  Soil_vs_Root_modern = genotypeSoil.Golm - genotypeRoot.modern,
  Soil_vs_Root_landrace = genotypeSoil.Golm - genotypeRoot.landrace,
  Soil_vs_Root_spontaneum = genotypeSoil.Golm - genotypeRoot.spontaneum,
  Soil_vs_Rhizosphere_modern = genotypeSoil.Golm - genotypeRhizosphere.modern,
  Soil_vs_Rhizosphere_landrace = genotypeSoil.Golm - genotypeRhizosphere.landrace,
  Soil_vs_Rhizosphere_spontaneum = genotypeSoil.Golm - genotypeRhizosphere.spontaneum,
  Root_vs_Rhizosphere_modern = genotypeRoot.modern - genotypeRhizosphere.modern,
  Root_vs_Rhizosphere_landrace = genotypeRoot.landrace - genotypeRhizosphere.landrace,
  Root_vs_Rhizosphere_spontaneum = genotypeRoot.spontaneum - genotypeRhizosphere.spontaneum,
  Root_modern_vs_sponteneum = genotypeRoot.modern - genotypeRoot.spontaneum,
  Root_landrace_vs_sponteneum = genotypeRoot.landrace - genotypeRoot.modern,
  Root_modern_vs_landrace = genotypeRoot.modern - genotypeRoot.landrace,
  Rhizosphere_modern_vs_spontaneum = genotypeRhizosphere.modern - genotypeRhizosphere.spontaneum,
  Rhizosphere_landrace_vs_spontaneum = genotypeRhizosphere.landrace - genotypeRhizosphere.spontaneum,
  Rhizosphere_modern_vs_landrace = genotypeRhizosphere.modern - genotypeRhizosphere.landrace,
  levels = model_genotype)
# Compute estimated coefficients and standard errors for the given contrasts
fit2_genotype <- contrasts.fit(fit_genotype, cont.matrix_genotype)
fit2_genotype <- eBayes(fit2_genotype)
#decideTests: by default lfc>0, BH correct
de_tab_genotype <- decideTests(fit2_genotype)

#Root effect: enriched from soil
Root_modern_families <- rownames(de_tab_genotype)[de_tab_genotype[,1] ==-1]
Root_landrace_families <- rownames(de_tab_genotype)[de_tab_genotype[,2] ==-1]
Root_spontaneum_families <- rownames(de_tab_genotype)[de_tab_genotype[,3] ==-1]
length(Root_modern_families)
length(Root_landrace_families)
length(Root_spontaneum_families)
Root_modern_families
Root_landrace_families
Root_spontaneum_families

#Rhizosphere effect: enriched from soil
Rhizo_modern_families <- rownames(de_tab_genotype)[de_tab_genotype[,4] ==-1]
Rhizo_landrace_families <- rownames(de_tab_genotype)[de_tab_genotype[,5] ==-1]
Rhizo_spontaneum_families <- rownames(de_tab_genotype)[de_tab_genotype[,6] ==-1]
length(Rhizo_modern_families)
length(Rhizo_landrace_families)
length(Rhizo_spontaneum_families)
Rhizo_modern_families
Rhizo_landrace_families
Rhizo_spontaneum_families

###########################################################
#Genotype effect corrected for Microhabitat  and Experiment
##########################################################


genotype <- as.vector(paste(design$Microhabitat, design$Experiment, design$Accession, sep="."))
model_genotype <- model.matrix(~0 + genotype)
colnames(model_genotype) <- make.names(colnames(model_genotype))
colnames(model_genotype)
#fit the linear model
fit_genotype <- lmFit(eset, model_genotype)
#Genotype effect Rhizosphere 1193R
cont.matrix_genotype <- makeContrasts(
  M_vs_L_3 = genotypeRhizosphere.Barley3.modern - genotypeRhizosphere.Barley3.landrace,
  M_vs_L_2 = genotypeRhizosphere.Barley2.modern - genotypeRhizosphere.Barley2.landrace,
  M_vs_S_3 = genotypeRhizosphere.Barley3.modern - genotypeRhizosphere.Barley3.spontaneum,
  M_vs_S_2 = genotypeRhizosphere.Barley2.modern - genotypeRhizosphere.Barley2.spontaneum,
  S_vs_L_3 = genotypeRhizosphere.Barley3.spontaneum - genotypeRhizosphere.Barley3.landrace,
  S_vs_L_2 = genotypeRhizosphere.Barley2.spontaneum - genotypeRhizosphere.Barley2.landrace,
  levels = model_genotype)
# Compute estimated coefficients and standard errors for the given contrasts
fit2_genotype <- contrasts.fit(fit_genotype, cont.matrix_genotype)
fit2_genotype <- eBayes(fit2_genotype)
#decideTests: by default lfc=>0, BH corrected
de_tab_genotype <- decideTests(fit2_genotype)
#identify relevant families
M_vs_L_3_families_1193_Rhizo <- rownames(de_tab_genotype)[de_tab_genotype[,1] ==1]
L_vs_M_3_families_1193_Rhizo <- rownames(de_tab_genotype)[de_tab_genotype[,1] == -1]
M_vs_L_2_families_1193_Rhizo <- rownames(de_tab_genotype)[de_tab_genotype[,2] ==1]
L_vs_M_2_families_1193_Rhizo <- rownames(de_tab_genotype)[de_tab_genotype[,2] == -1]
M_vs_S_3_families_1193_Rhizo <- rownames(de_tab_genotype)[de_tab_genotype[,3] ==1]
S_vs_M_3_families_1193_Rhizo <- rownames(de_tab_genotype)[de_tab_genotype[,3] == -1]
M_vs_S_2_families_1193_Rhizo <- rownames(de_tab_genotype)[de_tab_genotype[,4] ==1]
S_vs_M_2_families_1193_Rhizo <- rownames(de_tab_genotype)[de_tab_genotype[,4] == -1]
S_vs_L_3_families_1193_Rhizo <- rownames(de_tab_genotype)[de_tab_genotype[,5] == 1]
L_vs_S_3_families_1193_Rhizo <- rownames(de_tab_genotype)[de_tab_genotype[,5] == -1]
S_vs_L_2_families_1193_Rhizo <- rownames(de_tab_genotype)[de_tab_genotype[,6] == 1]
L_vs_S_2_families_1193_Rhizo <- rownames(de_tab_genotype)[de_tab_genotype[,6] == -1]
length(M_vs_L_3_families_1193_Rhizo)
length(L_vs_M_3_families_1193_Rhizo)
length(M_vs_L_2_families_1193_Rhizo)
length(L_vs_M_2_families_1193_Rhizo)
length(M_vs_S_3_families_1193_Rhizo)
length(S_vs_M_3_families_1193_Rhizo)
length(M_vs_S_2_families_1193_Rhizo)
length(S_vs_M_2_families_1193_Rhizo)
length(L_vs_S_3_families_1193_Rhizo)
length(L_vs_S_2_families_1193_Rhizo)
length(S_vs_L_3_families_1193_Rhizo)
length(S_vs_L_2_families_1193_Rhizo)
M_vs_L_Rhizo_families_1193 <- intersect (M_vs_L_3_families_1193_Rhizo, M_vs_L_2_families_1193_Rhizo)
M_vs_S_Rhizo_families_1193 <- intersect (M_vs_S_3_families_1193_Rhizo, M_vs_S_2_families_1193_Rhizo)
L_vs_M_Rhizo_families_1193 <- intersect (L_vs_M_3_families_1193_Rhizo, L_vs_M_2_families_1193_Rhizo)
L_vs_S_Rhizo_families_1193 <- intersect (L_vs_S_3_families_1193_Rhizo, L_vs_S_2_families_1193_Rhizo)
S_vs_M_Rhizo_families_1193 <- intersect (S_vs_M_3_families_1193_Rhizo, S_vs_M_2_families_1193_Rhizo)
S_vs_L_Rhizo_families_1193 <- intersect (S_vs_L_3_families_1193_Rhizo, S_vs_L_2_families_1193_Rhizo)
length(M_vs_L_Rhizo_families_1193)
length(M_vs_S_Rhizo_families_1193)
length(L_vs_M_Rhizo_families_1193)
length(L_vs_S_Rhizo_families_1193)
length(S_vs_M_Rhizo_families_1193)
length(S_vs_L_Rhizo_families_1193)

#Genotype effect Root
cont.matrix_genotype <- makeContrasts(
  M_vs_L_3 = genotypeRoot.Barley3.modern - genotypeRoot.Barley3.landrace,
  M_vs_L_2 = genotypeRoot.Barley2.modern - genotypeRoot.Barley2.landrace,
  M_vs_S_3 = genotypeRoot.Barley3.modern - genotypeRoot.Barley3.spontaneum,
  M_vs_S_2 = genotypeRoot.Barley2.modern - genotypeRoot.Barley2.spontaneum,
  S_vs_L_3 = genotypeRoot.Barley3.spontaneum - genotypeRoot.Barley3.landrace,
  S_vs_L_2 = genotypeRoot.Barley2.spontaneum - genotypeRoot.Barley2.landrace,
  levels = model_genotype)
# Compute estimated coefficients and standard errors for the given contrasts
fit2_genotype <- contrasts.fit(fit_genotype, cont.matrix_genotype)
fit2_genotype <- eBayes(fit2_genotype)
#decideTests: by default lfc>0, BH correct
de_tab_genotype <- decideTests(fit2_genotype)
#identify relevant families
M_vs_L_3_families_1193_Root <- rownames(de_tab_genotype)[de_tab_genotype[,1] ==1]
L_vs_M_3_families_1193_Root <- rownames(de_tab_genotype)[de_tab_genotype[,1] == -1]
M_vs_L_2_families_1193_Root <- rownames(de_tab_genotype)[de_tab_genotype[,2] ==1]
L_vs_M_2_families_1193_Root <- rownames(de_tab_genotype)[de_tab_genotype[,2] == -1]
M_vs_S_3_families_1193_Root <- rownames(de_tab_genotype)[de_tab_genotype[,3] ==1]
S_vs_M_3_families_1193_Root <- rownames(de_tab_genotype)[de_tab_genotype[,3] == -1]
M_vs_S_2_families_1193_Root <- rownames(de_tab_genotype)[de_tab_genotype[,4] ==1]
S_vs_M_2_families_1193_Root <- rownames(de_tab_genotype)[de_tab_genotype[,4] == -1]
S_vs_L_3_families_1193_Root <- rownames(de_tab_genotype)[de_tab_genotype[,5] == 1]
L_vs_S_3_families_1193_Root <- rownames(de_tab_genotype)[de_tab_genotype[,5] == -1]
S_vs_L_2_families_1193_Root <- rownames(de_tab_genotype)[de_tab_genotype[,6] == 1]
L_vs_S_2_families_1193_Root <- rownames(de_tab_genotype)[de_tab_genotype[,6] == -1]
length(M_vs_L_3_families_1193_Root)
length(L_vs_M_3_families_1193_Root)
length(M_vs_L_2_families_1193_Root)
length(L_vs_M_2_families_1193_Root)
length(M_vs_S_3_families_1193_Root)
length(S_vs_M_3_families_1193_Root)
length(M_vs_S_2_families_1193_Root)
length(S_vs_M_2_families_1193_Root)
length(L_vs_S_3_families_1193_Root)
length(L_vs_S_2_families_1193_Root)
M_vs_L_Root_families_1193 <- intersect (M_vs_L_3_families_1193_Root, M_vs_L_2_families_1193_Root)
M_vs_S_Root_families_1193 <- intersect (M_vs_S_3_families_1193_Root, M_vs_S_2_families_1193_Root)
L_vs_M_Root_families_1193 <- intersect (L_vs_M_3_families_1193_Root, L_vs_M_2_families_1193_Root)
L_vs_S_Root_families_1193 <- intersect (L_vs_S_3_families_1193_Root, L_vs_S_2_families_1193_Root)
S_vs_M_Root_families_1193 <- intersect (S_vs_M_3_families_1193_Root, S_vs_M_2_families_1193_Root)
S_vs_L_Root_families_1193 <- intersect (S_vs_L_3_families_1193_Root, S_vs_L_2_families_1193_Root)
length(M_vs_L_Root_families_1193)
length(M_vs_S_Root_families_1193)
length(L_vs_M_Root_families_1193)
length(L_vs_S_Root_families_1193)
length(S_vs_M_Root_families_1193)
length(S_vs_L_Root_families_1193)

###########################################################
#END
##########################################################
