#############################################################
#
# Ref to the ARTICLE
# 
# Davide Bulgarelli
# d.bulgarelli@dundee.ac.uk
# 01/12/2014
# script to reproduce figure 3, S1 and associated statistical analyses
# files needed are comprised as individual worksheets in the Database S1. 
#"371A_530A_design.txt" worksheet Design_Barley
#"dat_info_Barley_OTUPARSE_NM_QIIME_ready.txt"  worksheet ws2
#"dat_info_Barley_OTUPARSE_NM_logth05_QIIME_ready.txt" ws3
#"dat_info_Barley_OTUPARSE_NM_sorted_1000_observed_OTUs.txt" worksheet ws4
#"dat_info_Barley_OTUPARSE_NM_sorted_1000_chao.txt" worksheet ws5
#"dat_info_Barley_OTUPARSE_NM_sorted_1000_shannon.txt" worksheet ws6 
#"bray_curtis_dat_info_Barley_OTUPARSE_NM_th.txt" worksheet ws7
#"unweighted_unifrac_dat_info_Barley_OTUPARSE_NM_th.txt" worksheet ws8
#"weighted_unifrac_dat_info_Barley_OTUPARSE_NM_th" worksheet ws9
#
#The file "371A_530A_UPARSE_otus_NC_ID_tax_assignments_QIIME_compatible_R.txt" can be retrieved in the folder "Bulgarelli_et_al_figures_1-3-4-S1_R_scripts"
#
#This script can be used to identify Root enriched OTUs in Arabidopsis plant grwon in Golm Soil 
#(see Bulgarelli et al., 2012, Nature 488:91)
#Files needed are included in the folder "Bulgarelli_et_al_figures_1-3-4-S1_R_scripts"
#""Libs_At_Golm_UPARSE_design.txt"
#"Libs_At_Golm_UPARSE_OTU_count.txt"
#"Libs_At_Golm_HQ_UPARSE_otus_NC_ID_tax_assignments.txt"
#############################################################


#############################################################
# Libraries and functions required
#############################################################

rm(list=ls())

#set working directory
setwd("C:/Users/DB42008/ownCloud/Manuscripts/Barley_Microbiota_revisionCHM0814_scripts/Bulgarelli_et_al_figures_1-3-4-S1_R_scripts")

library("limma")
library("marray")
library("Biobase")
library("gplots")
library("sciplot")
library("Hmisc")
library("vegan")
library("Formula")
library("multcomp")
source("file2Exprs.R")
source("tern_e.R")

######################
#Figure S1
######################

# upload the design file
design <- read.delim("371A_530A_design.txt", sep = "\t", header=TRUE )
rownames(design) <- design[,1]
dim(design)
design

#observed OTUs (Fig. S1A)
#pre-processing of the data
dat_371A_530A_observed_OTUs <- read.delim("dat_info_Barley_OTUPARSE_NM_sorted_1000_observed_OTUs.txt", sep = "\t", row.names=1, header=T, blank.lines.skip = FALSE)
colnames(dat_371A_530A_observed_OTUs)
dim(dat_371A_530A_observed_OTUs)
dat_371A_530A_observed_OTUs_info <- cbind(design, dat_371A_530A_observed_OTUs)
dat_371A_530A_observed_OTUs_info
#generate a box plot Microhabitat * experiment
#re-order the factors
dat_371A_530A_observed_OTUs_info$Experiment <- ordered(dat_371A_530A_observed_OTUs_info$Experiment, levels=c("Barley2", "Barley3"))
dat_371A_530A_observed_OTUs_info$Microhabitat <- ordered(dat_371A_530A_observed_OTUs_info$Microhabitat, levels=c("Soil", "Rhizosphere", "Root"))
with(dat_371A_530A_observed_OTUs_info, boxplot(observed_species ~ Microhabitat * Experiment, xlab = "Samples", ylab = "Observed OTUs",   main = "Observed OTUs dataset 371A_530A"))

#Two-way anova
OTUs_observed_stats <- aov(dat_371A_530A_observed_OTUs_info$observed_species~Microhabitat * Experiment, data = dat_371A_530A_observed_OTUs_info)
summary(OTUs_observed_stats)

#tukey HSD test 
Tukey_HSD_OTUs_observed <- TukeyHSD(OTUs_observed_stats)

#create a data frame for the inspection of Tukey data
Tukey_HSD_OTUs_observed_table <- as.data.frame(Tukey_HSD_OTUs_observed$`Microhabitat:Experiment`)
Tukey_HSD_OTUs_observed_table[order(Tukey_HSD_OTUs_observed_table$p, decreasing=TRUE), ]
#write.table(Tukey_HSD_OTUs_observed_table[order(Tukey_HSD_OTUs_observed_table$p, decreasing=TRUE), ], file="Tukey_Observed_OTUs_stats_wt_OTUPARSE_1000.txt", sep="\t")

#chao1 (Fig. S1B)
#pre-processing of the data
dat_371A_530A_chao1 <- read.delim("dat_info_Barley_OTUPARSE_NM_sorted_1000_chao.txt", sep = "\t", row.names=1, header=T, blank.lines.skip = FALSE)
colnames(dat_371A_530A_chao1)
dim(dat_371A_530A_chao1)
dat_371A_530A_chao1_info <- cbind(design, dat_371A_530A_chao1)
#generate a box plot Microhabitat * experiment
#re-order the factors
dat_371A_530A_chao1_info$Experiment <- ordered(dat_371A_530A_chao1_info$Experiment, levels=c("Barley2", "Barley3"))
dat_371A_530A_chao1_info$Microhabitat <- ordered(dat_371A_530A_chao1_info$Microhabitat, levels=c("Soil", "Rhizosphere", "Root"))
with(dat_371A_530A_chao1_info, boxplot(chao1 ~ Microhabitat * Experiment, xlab = "Samples", ylab = "Estimated OTUs",   main = "Chao1 dataset 371A_530A"))

#Two-way anova
chao1_stats <- aov(dat_371A_530A_chao1_info$chao1~Microhabitat * Experiment, data = dat_371A_530A_chao1_info)
summary(chao1_stats) 

#tukey HSD 
Tukey_HSD_chao1 <- TukeyHSD(chao1_stats)

#create a data frame for the inspection of Tukey data
Tukey_HSD_chao1_table <- as.data.frame(Tukey_HSD_chao1$`Microhabitat:Experiment`)
Tukey_HSD_chao1_table[order(Tukey_HSD_chao1_table$p, decreasing=TRUE), ]
#write.table(Tukey_HSD_chao1_table[order(Tukey_HSD_chao1_table$p, decreasing=TRUE), ], file="Tukey_chao1_stats_wt_OTUPARSE_1000.txt", sep="\t")

#shannon diversity index (Fig. S1C)
#pre-processing of the data
dat_371A_530A_shannon <- read.delim("dat_info_Barley_OTUPARSE_NM_sorted_1000_shannon.txt", sep = "\t", row.names=1, header=T, blank.lines.skip = FALSE)
colnames(dat_371A_530A_shannon)
dim(dat_371A_530A_shannon)
dat_371A_530A_shannon_info <- cbind(design, dat_371A_530A_shannon)
#generate a box plot Microhabitat * experiment
#re-order the factors
dat_371A_530A_shannon_info$Experiment <- ordered(dat_371A_530A_shannon_info$Experiment, levels=c("Barley2", "Barley3"))
dat_371A_530A_shannon_info$Microhabitat <- ordered(dat_371A_530A_shannon_info$Microhabitat, levels=c("Soil", "Rhizosphere", "Root"))
with(dat_371A_530A_shannon_info, boxplot(shannon ~ Microhabitat * Experiment, xlab = "Samples", ylab = "Shannon index",   main = "shannon dataset 371A_530A"))

#Two-way anova
shannon_stats <- aov(dat_371A_530A_shannon_info$shannon~Microhabitat * Experiment, data = dat_371A_530A_shannon_info)
summary(shannon_stats)

#tukey HSD test 
Tukey_HSD_shannon <- TukeyHSD(shannon_stats)

#create a data frame for the inspection of Tukey data
Tukey_HSD_shannon_table <- as.data.frame(Tukey_HSD_shannon$`Microhabitat:Experiment`)
Tukey_HSD_shannon_table[order(Tukey_HSD_shannon_table$p, decreasing=TRUE), ]
#write.table(Tukey_HSD_shannon_table[order(Tukey_HSD_shannon_table$p, decreasing=TRUE), ], file="Tukey_shannon_stats_wt_OTUPARSE_1000.txt", sep="\t")

###individual plots saved as .eps and combined in Adobe Illustrator



###########
#Figure 3
###########

#upload the OTU table with taxonomy information
dat_info_Barley_OTUPARSE <- read.delim("dat_info_Barley_OTUPARSE_NM_QIIME_ready.txt", row.names= 1,  header=T, sep="\t")
dat_info_Barley_OTUPARSE_th <- read.delim("dat_info_Barley_OTUPARSE_NM_logth05_QIIME_ready.txt", row.names= 1,  header=T, sep="\t")

#extract the count data
dat_count <- dat_info_Barley_OTUPARSE[, 1:42]

#uniform the order of the samples
dat_log <- dat_info_Barley_OTUPARSE_th[, 1:42]
dat_log <- dat_log[, rownames(design)]
dat_log <- as.matrix(dat_log)

#check the order name
rownames(design)
colnames(dat_log)

eset <- new("ExpressionSet")
exprs(eset) <- dat_log
pData(eset) <- design

#define the factor Microhabitat corrected for Accession
genotype <- as.vector(paste(design$Microhabitat, design$Accession, sep="."))
model_genotype <- model.matrix(~0 + genotype)
colnames(model_genotype) <- make.names(colnames(model_genotype))
colnames(model_genotype)
#fit the linear model
fit_genotype <- lmFit(eset, model_genotype)
#Microhabitat * Accession effect
cont.matrix_genotype <- makeContrasts(
  Soil_vs_Root_modern = genotypeSoil.Golm - genotypeRoot.modern,
  Soil_vs_Root_landrace = genotypeSoil.Golm - genotypeRoot.landrace,
  Soil_vs_Root_spontaneum = genotypeSoil.Golm - genotypeRoot.spontaneum,
  Soil_vs_Rhizosphere_modern = genotypeSoil.Golm - genotypeRhizosphere.modern,
  Soil_vs_Rhizosphere_landrace = genotypeSoil.Golm - genotypeRhizosphere.landrace,
  Soil_vs_Rhizosphere_spontaneum = genotypeSoil.Golm - genotypeRhizosphere.spontaneum,
  Root_vs_Rhizosphere_modern = genotypeRoot.modern - genotypeRhizosphere.modern,
  Root_vs_Rhizosphere_landrace = genotypeRoot.landrace - genotypeRhizosphere.landrace,
  Root_vs_Rhizosphere_spontaneum = genotypeRoot.spontaneum - genotypeRhizosphere.spontaneum,
  Root_modern_vs_sponteneum = genotypeRoot.modern - genotypeRoot.spontaneum,
  Root_landrace_vs_sponteneum = genotypeRoot.landrace - genotypeRoot.modern,
  Root_modern_vs_landrace = genotypeRoot.modern - genotypeRoot.landrace,
  Rhizosphere_modern_vs_spontaneum = genotypeRhizosphere.modern - genotypeRhizosphere.spontaneum,
  Rhizosphere_landrace_vs_spontaneum = genotypeRhizosphere.landrace - genotypeRhizosphere.spontaneum,
  Rhizosphere_modern_vs_landrace = genotypeRhizosphere.modern - genotypeRhizosphere.landrace,
  levels = model_genotype)
# Compute estimated coefficients and standard errors for the given contrasts
fit2_genotype <- contrasts.fit(fit_genotype, cont.matrix_genotype)
fit2_genotype <- eBayes(fit2_genotype)
#decideTests: by default lfc>0, BH correct
de_tab_genotype <- decideTests(fit2_genotype)

#Root effect: enriched from soil
Root_modern_OTUs <- rownames(de_tab_genotype)[de_tab_genotype[,1] ==-1]
Root_landrace_OTUs <- rownames(de_tab_genotype)[de_tab_genotype[,2] ==-1]
Root_spontaneum_OTUs <- rownames(de_tab_genotype)[de_tab_genotype[,3] ==-1]
length(Root_modern_OTUs)
length(Root_landrace_OTUs)
length(Root_spontaneum_OTUs)

#Determine the vector of Root enriched barley OTUs and construct an OTU table with root enriched OTUs (needed for Figure4)
Barley_Root_OTUs_ml <- intersect(Root_modern_OTUs, Root_landrace_OTUs)
Barley_Root_OTUs_mls <-intersect(Barley_Root_OTUs_ml, Root_spontaneum_OTUs)
length(Barley_Root_OTUs_mls)
dat_info_Barley_Root_OTUs_mls <- dat_info_Barley_OTUPARSE[Barley_Root_OTUs_mls, 1:43]
#write.table(dat_info_Barley_Root_OTUs_mls, file="dat_info_Barley_Root_OTUs_OTUPARSE.txt", sep="\t")
#calculate the proportion of this core OTUs on the total amount of reads assigned to Root samples
stat_root_otus <- median(colSums(dat_info_Barley_Root_OTUs_mls[, 25:42]))/median(colSums(dat_info_Barley_OTUPARSE[, 25:42]))
#0.368369

#Rhizosphere effect: enriched from soil
Rhizo_modern_OTUs <- rownames(de_tab_genotype)[de_tab_genotype[,4] ==-1]
Rhizo_landrace_OTUs <- rownames(de_tab_genotype)[de_tab_genotype[,5] ==-1]
Rhizo_spontaneum_OTUs <- rownames(de_tab_genotype)[de_tab_genotype[,6] ==-1]
length(Rhizo_modern_OTUs)
length(Rhizo_landrace_OTUs)
length(Rhizo_spontaneum_OTUs)
#calculate the proportion of the Rhizo_OTUs on the total amount of reads assigned to rhizosphere samples
stat_rhizo_OTUs_spontaneum <- median(colSums(dat_count[Rhizo_spontaneum_OTUs, rownames(design)[which(design$Description == "Rhizospontaneum")]]))/median(colSums(dat_count[, rownames(design)[which(design$Description == "Rhizospontaneum")]]))
stat_rhizo_OTUs_landrace <- median(colSums(dat_count[Rhizo_landrace_OTUs, rownames(design)[which(design$Description == "Rhizolandrace")]]))/median(colSums(dat_count[, rownames(design)[which(design$Description == "Rhizolandrace")]]))
stat_rhizo_OTUs_modern <- median(colSums(dat_count[Rhizo_modern_OTUs, rownames(design)[which(design$Description == "Rhizomodern")]]))/median(colSums(dat_count[, rownames(design)[which(design$Description == "Rhizomodern")]]))

#RR OTUs: enriched both in rhizosphere and root microhabitats
RR_OTUs_modern <- intersect(Root_modern_OTUs, Rhizo_modern_OTUs)
RR_OTUs_landrace <- intersect(Root_landrace_OTUs, Rhizo_landrace_OTUs)
RR_OTUs_spontaneum <- intersect(Root_spontaneum_OTUs, Rhizo_spontaneum_OTUs)
length(RR_OTUs_modern)
length(RR_OTUs_landrace)
length(RR_OTUs_spontaneum)

#correct for double assignment: Rhizosphere
Rhizo_modern_OTUs_correct <- setdiff(Rhizo_modern_OTUs, RR_OTUs_modern) 
length(Rhizo_modern_OTUs_correct)
Rhizo_landrace_OTUs_correct <- setdiff(Rhizo_landrace_OTUs, RR_OTUs_landrace) 
length(Rhizo_landrace_OTUs_correct)
Rhizo_spontaneum_OTUs_correct <- setdiff(Rhizo_spontaneum_OTUs, RR_OTUs_spontaneum) 
length(Rhizo_spontaneum_OTUs_correct)

#correct for double assignment: Root
Root_modern_OTUs_correct <- setdiff(Root_modern_OTUs, RR_OTUs_modern) 
length(Root_modern_OTUs_correct)
Root_landrace_OTUs_correct <- setdiff(Root_landrace_OTUs, RR_OTUs_landrace) 
length(Root_landrace_OTUs_correct)
Root_spontaneum_OTUs_correct <- setdiff(Root_spontaneum_OTUs, RR_OTUs_spontaneum) 
length(Root_spontaneum_OTUs_correct)



#generate OTU tables per community-type to extract count and taxonomy information 
#spontaneum (worksheet ws10, Database S1)
dat_info_Root_spontaneum_OTUs_correct <- dat_info_Barley_OTUPARSE[Root_spontaneum_OTUs_correct, ]
dat_info_Rhizo_spontaneum_OTUs_correct <- dat_info_Barley_OTUPARSE[Rhizo_spontaneum_OTUs_correct, ]
dat_info_RR_OTUs_spontaneum <- dat_info_Barley_OTUPARSE[RR_OTUs_spontaneum, ]

#landrace (worksheet ws11, Database S1)
dat_info_Root_landrace_OTUs_correct <- dat_info_Barley_OTUPARSE[Root_landrace_OTUs_correct, ]
dat_info_Rhizo_landrace_OTUs_correct <- dat_info_Barley_OTUPARSE[Rhizo_landrace_OTUs_correct, ]
dat_info_RR_OTUs_landrace <- dat_info_Barley_OTUPARSE[RR_OTUs_landrace, ]

#modern (worksheet ws12, Database S1)
dat_info_Root_modern_OTUs_correct <- dat_info_Barley_OTUPARSE[Root_modern_OTUs_correct, ]
dat_info_Rhizo_modern_OTUs_correct <- dat_info_Barley_OTUPARSE[Rhizo_modern_OTUs_correct, ]
dat_info_RR_OTUs_modern <- dat_info_Barley_OTUPARSE[RR_OTUs_modern, ]

#Create a list of unique RR_OTUs and Rhizo_OTUs ids to identify their representative sequences
Barley_RR_Rhizo_OTUs <- c(RR_OTUs_spontaneum, RR_OTUs_landrace, RR_OTUs_modern, Rhizo_spontaneum_OTUs_correct, Rhizo_landrace_OTUs_correct, Rhizo_modern_OTUs_correct)
Barley_RR_Rhizo_OTUs_unique <- unique(Barley_RR_Rhizo_OTUs)
length(Barley_RR_Rhizo_OTUs_unique)
dat_info_Barley_RR_Rhizo_OTUs_unique <- dat_info_Barley_OTUPARSE[Barley_RR_Rhizo_OTUs_unique, 1:43]

#visualize the data using ternary plots

#determine the order of the coefficient
dev.off()
fit_genotype$coef
means_rhizo_L <- as.data.frame(fit_genotype$coef[,1])
means_rhizo_M <- as.data.frame(fit_genotype$coef[,2])
means_rhizo_S <- as.data.frame(fit_genotype$coef[,3])
means_root_L <- as.data.frame(fit_genotype$coef[,4])
means_root_M <- as.data.frame(fit_genotype$coef[,5])
means_root_S <- as.data.frame(fit_genotype$coef[,6])
means_soil <- as.data.frame(fit_genotype$coef[,7])
colnames(means_rhizo_L) <- c("Means")
colnames(means_rhizo_M) <- c("Means")
colnames(means_rhizo_S) <- c("Means")
colnames(means_root_L) <- c("Means")
colnames(means_root_M) <- c("Means")
colnames(means_root_S) <- c("Means")
colnames(means_soil) <- c("Means")
#set negative values to 0
means_rhizo_L <- ifelse(rowSums(means_rhizo_L) < 0, 0, rowSums(means_rhizo_L))
means_rhizo_M <- ifelse(rowSums(means_rhizo_M) < 0, 0, rowSums(means_rhizo_M))
means_rhizo_S <- ifelse(rowSums(means_rhizo_S) < 0, 0, rowSums(means_rhizo_S))
means_root_L <- ifelse(rowSums(means_root_L) < 0, 0, rowSums(means_root_L))
means_root_M <- ifelse(rowSums(means_root_M) < 0, 0, rowSums(means_root_M))
means_root_S <- ifelse(rowSums(means_root_S) < 0, 0, rowSums(means_root_S))
means_soil <- ifelse(rowSums(means_soil) < 0, 0, rowSums(means_soil))

#generate the matrix for the ternary plot

#Spontaneum (Fig 3A)
temat_1A <- cbind(means_root_S, means_rhizo_S , means_soil)
colnames(temat_1A) <- c("Root", "Rhizosphere", "Soil")
dim(temat_1A)
#remove 0 count
temat_1A = temat_1A[ rowSums(temat_1A)!=0, ]
fig1a_colors <- ifelse(rownames(temat_1A) %in% RR_OTUs_spontaneum , "lightblue","darkgrey")
names(fig1a_colors) <- rownames(temat_1A)
fig1a_colors[Rhizo_spontaneum_OTUs_correct] <- "magenta"
fig1a_colors[Root_spontaneum_OTUs_correct] <- "blue"
tern_e(temat_1A, prop=T, col=fig1a_colors, grid_color="black", labels_color="black", pch=19, main="Figure 3a")

#Landrace
temat_1A <- cbind(means_root_L, means_rhizo_L, means_soil)
colnames(temat_1A) <- c("Root", "Rhizosphere", "Soil")
dim(temat_1A)
#remove 0 count
temat_1A = temat_1A[ rowSums(temat_1A)!=0, ]
fig1a_colors <- ifelse(rownames(temat_1A) %in% RR_OTUs_landrace , "lightblue","darkgrey")
names(fig1a_colors) <- rownames(temat_1A)
fig1a_colors[Rhizo_landrace_OTUs_correct] <- "magenta"
fig1a_colors[Root_landrace_OTUs_correct] <- "blue"
tern_e(temat_1A, prop=T, col=fig1a_colors, grid_color="black", labels_color="black", pch=19, main="Figure 3b")

#Modern
temat_1A <- cbind(means_root_M, means_rhizo_M, means_soil)
colnames(temat_1A) <- c("Root", "Rhizosphere", "Soil")
dim(temat_1A)
#remove 0 count
temat_1A = temat_1A[ rowSums(temat_1A)!=0, ]
fig1a_colors <- ifelse(rownames(temat_1A) %in% RR_OTUs_modern , "lightblue","darkgrey")
names(fig1a_colors) <- rownames(temat_1A)
fig1a_colors[Rhizo_modern_OTUs_correct] <- "magenta"
fig1a_colors[Root_modern_OTUs_correct] <- "blue"
tern_e(temat_1A, prop=T, col=fig1a_colors, grid_color="black", labels_color="black", pch=19, main="Figure 3c")
#end


#calculate the amount of reads per subcommunity per Microhabitat
#create vectors for the description
genotypeSoil <- c("Bulk10", "Bulk11", "Bulk12", "Bulk20", "Bulk22", "Bulk23")
genotypeRhizosphere_spontaneum <- c("HIDRhizo10", "HIDRhizo11", "HIDRhizo12", "HIDRhizo20", "HIDRhizo21", "HIDRhizo22")
genotypeRhizosphere_landrace <- c("RumRhizo10", "RumRhizo11", "RumRhizo12", "RumRhizo20", "RumRhizo21", "RumRhizo22")
genotypeRhizosphere_modern<- c("MorexRhizo10", "MorexRhizo11", "MorexRhizo12", "MorexRhizo20", "MorexRhizo22", "MorexRhizo23")
genotypeRoot_spontaneum <- c("HIDRoot10", "HIDRoot11", "HIDRoot12", "HIDRoot20", "HIDRoot21", "HIDRoot22")
genotypeRoot_landrace <- c("RumRoot10", "RumRoot11", "RumRoot12", "RumRoot20", "RumRoot21", "RumRoot22")
genotypeRoot_modern<- c("MorexRoot10", "MorexRoot11", "MorexRoot12", "MorexRoot20", "MorexRoot22", "MorexRoot23")
genotype_RR_spontaneum <- c(genotypeRhizosphere_spontaneum, genotypeRoot_spontaneum)
genotype_RR_landrace <- c(genotypeRhizosphere_landrace, genotypeRoot_landrace)
genotype_RR_modern <- c(genotypeRhizosphere_modern, genotypeRoot_modern)

#RR OTUs
genotype_RR_RROTUs_spontaneum_sum_reads <- as.data.frame(dat_count[RR_OTUs_spontaneum, genotype_RR_spontaneum])
rownames(genotype_RR_RROTUs_spontaneum_sum_reads) <- rownames(dat_count[RR_OTUs_spontaneum, ])
colnames(genotype_RR_RROTUs_spontaneum_sum_reads) <- genotype_RR_spontaneum
genotype_RR_RROTUs_spontaneum_sum_reads
genotype_RR_RROTUs_landrace_sum_reads <- as.data.frame(dat_count[RR_OTUs_landrace, genotype_RR_landrace])
rownames(genotype_RR_RROTUs_landrace_sum_reads) <- rownames(dat_count[RR_OTUs_landrace, ])
colnames(genotype_RR_RROTUs_landrace_sum_reads) <- genotype_RR_landrace
genotype_RR_RROTUs_landrace_sum_reads
genotype_RR_RROTUs_modern_sum_reads <- as.data.frame(dat_count[RR_OTUs_modern, genotype_RR_modern])
rownames(genotype_RR_RROTUs_modern_sum_reads) <- rownames(dat_count[RR_OTUs_modern, ])
colnames(genotype_RR_RROTUs_modern_sum_reads) <- genotype_RR_modern
genotype_RR_RROTUs_modern_sum_reads 
median_RR_in_spontaneum <-  median(colSums(genotype_RR_RROTUs_spontaneum_sum_reads))/median(colSums(dat_count[,genotype_RR_spontaneum])) 
median_RR_in_landrace <-  median(colSums(genotype_RR_RROTUs_landrace_sum_reads))/median(colSums(dat_count[,genotype_RR_landrace])) 
median_RR_in_modern <-  median(colSums(genotype_RR_RROTUs_modern_sum_reads))/median(colSums(dat_count[,genotype_RR_modern])) 

#Root_OTUs
genotypeRoot_OTUs_spontaneum_sum_reads <- as.data.frame(dat_count[Root_spontaneum_OTUs_correct, genotypeRoot_spontaneum])
rownames(genotypeRoot_OTUs_spontaneum_sum_reads) <- rownames(dat_count[Root_spontaneum_OTUs_correct, ])
colnames(genotypeRoot_OTUs_spontaneum_sum_reads) <- genotypeRoot_spontaneum
genotypeRoot_OTUs_spontaneum_sum_reads
genotypeRoot_OTUs_landrace_sum_reads <- as.data.frame(dat_count[Root_landrace_OTUs_correct, genotypeRoot_landrace])
rownames(genotypeRoot_OTUs_landrace_sum_reads) <- rownames(dat_count[Root_landrace_OTUs_correct, ])
colnames(genotypeRoot_OTUs_landrace_sum_reads) <- genotypeRoot_landrace
genotypeRoot_OTUs_landrace_sum_reads
genotypeRoot_OTUs_modern_sum_reads <- as.data.frame(dat_count[Root_modern_OTUs_correct, genotypeRoot_modern])
rownames(genotypeRoot_OTUs_modern_sum_reads) <- rownames(dat_count[Root_modern_OTUs_correct, ])
colnames(genotypeRoot_OTUs_modern_sum_reads) <- genotypeRoot_modern
genotypeRoot_OTUs_modern_sum_reads
median_Root_OTUs_in_spontaneum <-  median(colSums(genotypeRoot_OTUs_spontaneum_sum_reads))/median(colSums(dat_count[,genotypeRoot_spontaneum])) 
median_Root_OTUs_in_landrace <-  median(colSums(genotypeRoot_OTUs_landrace_sum_reads))/median(colSums(dat_count[,genotypeRoot_landrace])) 
median_Root_OTUs_in_modern <-  median(colSums(genotypeRoot_OTUs_modern_sum_reads))/median(colSums(dat_count[,genotypeRoot_modern])) 

#Rhizosphere OTUs
genotypeRhizosphere_OTUs_spontaneum_sum_reads <- as.data.frame(dat_count[Rhizo_spontaneum_OTUs_correct, genotypeRhizosphere_spontaneum])
rownames(genotypeRhizosphere_OTUs_spontaneum_sum_reads) <- rownames(dat_count[Rhizo_spontaneum_OTUs_correct, ])
colnames(genotypeRhizosphere_OTUs_spontaneum_sum_reads) <- genotypeRhizosphere_spontaneum
genotypeRhizosphere_OTUs_spontaneum_sum_reads
genotypeRhizosphere_OTUs_landrace_sum_reads <- as.data.frame(dat_count[Rhizo_landrace_OTUs_correct, genotypeRhizosphere_landrace])
rownames(genotypeRhizosphere_OTUs_landrace_sum_reads) <- rownames(dat_count[Rhizo_landrace_OTUs_correct, ])
colnames(genotypeRhizosphere_OTUs_landrace_sum_reads) <- genotypeRhizosphere_landrace
genotypeRhizosphere_OTUs_landrace_sum_reads
genotypeRhizosphere_OTUs_modern_sum_reads <- as.data.frame(dat_count[Rhizo_modern_OTUs_correct, genotypeRhizosphere_modern])
rownames(genotypeRhizosphere_OTUs_modern_sum_reads) <- rownames(dat_count[Rhizo_modern_OTUs_correct, ])
colnames(genotypeRhizosphere_OTUs_modern_sum_reads) <- genotypeRhizosphere_modern
genotypeRhizosphere_OTUs_modern_sum_reads
median_Rhizosphere_OTUs_in_spontaneum <-  median(colSums(genotypeRhizosphere_OTUs_spontaneum_sum_reads))/median(colSums(dat_count[,genotypeRhizosphere_spontaneum])) 
median_Rhizosphere_OTUs_in_landrace <-  median(colSums(genotypeRhizosphere_OTUs_landrace_sum_reads))/median(colSums(dat_count[,genotypeRhizosphere_landrace])) 
median_Rhizosphere_OTUs_in_modern <-  median(colSums(genotypeRhizosphere_OTUs_modern_sum_reads))/median(colSums(dat_count[,genotypeRhizosphere_modern])) 



#pie chart subcommunities
#Root_OTUs_spontaneum
#import the taxonomy information R compatible
dat_tax2 <- read.delim("371A_530A_UPARSE_otus_NC_ID_tax_assignments_QIIME_compatible_R.txt", sep="\t", row.names=1, header=T, blank.lines.skip = FALSE)
dat_class_Root_spontaneum <- as.matrix(dat_tax2[Root_spontaneum_OTUs_correct, 2])
rownames(dat_class_Root_spontaneum) <- Root_spontaneum_OTUs_correct
genotypeRoot_OTUs_spontaneum_sum_reads_tax <- cbind(genotypeRoot_OTUs_spontaneum_sum_reads, dat_class_Root_spontaneum)
genotypeRoot_OTUs_spontaneum_sum_reads_tax_ordered <- as.matrix(genotypeRoot_OTUs_spontaneum_sum_reads_tax[order(genotypeRoot_OTUs_spontaneum_sum_reads_tax[,7]), ])
genotypeRoot_OTUs_spontaneum_sum_reads_tax_ordered 
genotypeRoot_OTUs_spontaneum_sum_reads_tax_ordered_count <- genotypeRoot_OTUs_spontaneum_sum_reads[rownames(genotypeRoot_OTUs_spontaneum_sum_reads_tax_ordered), ] 
taxa_pie_colors_root_s <- ifelse(genotypeRoot_OTUs_spontaneum_sum_reads_tax_ordered[,7] == "c__Actinobacteria" , "red", 
                               (ifelse(genotypeRoot_OTUs_spontaneum_sum_reads_tax_ordered[,7] == "c__Alphaproteobacteria", "deepskyblue", 
                                       (ifelse(genotypeRoot_OTUs_spontaneum_sum_reads_tax_ordered[,7] == "c__Betaproteobacteria", "darkorange", 
                                               (ifelse(genotypeRoot_OTUs_spontaneum_sum_reads_tax_ordered[,7] == "c__Gammaproteobacteria", "forestgreen",
                                                       (ifelse(genotypeRoot_OTUs_spontaneum_sum_reads_tax_ordered[,7] == "c__Flavobacteriia", "blueviolet", "black")))))))))        
#RR_OTUs_spontaneum
dat_class_RR_spontaneum <- as.matrix(dat_tax2[RR_OTUs_spontaneum, 2])
rownames(dat_class_RR_spontaneum) <- RR_OTUs_spontaneum
genotype_RR_RROTUs_spontaneum_sum_reads_tax <- cbind(genotype_RR_RROTUs_spontaneum_sum_reads, dat_class_RR_spontaneum)
genotype_RR_RROTUs_spontaneum_sum_reads_tax_ordered <- as.matrix(genotype_RR_RROTUs_spontaneum_sum_reads_tax[order(genotype_RR_RROTUs_spontaneum_sum_reads_tax[,13]), ])
genotype_RR_RROTUs_spontaneum_sum_reads_tax_ordered
genotype_RR_RROTUs_spontaneum_sum_reads_tax_ordered_count <- genotype_RR_RROTUs_spontaneum_sum_reads[rownames(genotype_RR_RROTUs_spontaneum_sum_reads_tax_ordered), ] 
taxa_pie_colors_RR_s <- ifelse(genotype_RR_RROTUs_spontaneum_sum_reads_tax_ordered[,13] == "c__Actinobacteria" , "red", 
                                 (ifelse(genotype_RR_RROTUs_spontaneum_sum_reads_tax_ordered[,13] == "c__Alphaproteobacteria", "deepskyblue", 
                                         (ifelse(genotype_RR_RROTUs_spontaneum_sum_reads_tax_ordered[,13] == "c__Betaproteobacteria", "darkorange", 
                                                 (ifelse(genotype_RR_RROTUs_spontaneum_sum_reads_tax_ordered[,13] == "c__Gammaproteobacteria", "forestgreen",
                                                         (ifelse(genotype_RR_RROTUs_spontaneum_sum_reads_tax_ordered[,13] == "c__Flavobacteriia", "blueviolet", "black")))))))))        
#Rhizo_OTUs_spontaneum
dat_class_rhizo_spontaneum <- as.matrix(dat_tax2[Rhizo_spontaneum_OTUs_correct, 2])
rownames(dat_class_rhizo_spontaneum) <- Rhizo_spontaneum_OTUs_correct
genotypeRhizosphere_OTUs_spontaneum_sum_reads_tax <- cbind(genotypeRhizosphere_OTUs_spontaneum_sum_reads, dat_class_rhizo_spontaneum)
genotypeRhizosphere_OTUs_spontaneum_sum_reads_tax_ordered <- as.matrix(genotypeRhizosphere_OTUs_spontaneum_sum_reads_tax[order(genotypeRhizosphere_OTUs_spontaneum_sum_reads_tax[,7]), ])
genotypeRhizosphere_OTUs_spontaneum_sum_reads_tax_ordered
genotypeRhizosphere_OTUs_spontaneum_sum_reads_tax_ordered_count <- genotypeRhizosphere_OTUs_spontaneum_sum_reads[rownames(genotypeRhizosphere_OTUs_spontaneum_sum_reads_tax_ordered), ] 
taxa_pie_colors_rhizo_s <- ifelse(genotypeRhizosphere_OTUs_spontaneum_sum_reads_tax_ordered[,7] == "c__Actinobacteria" , "red", 
                               (ifelse(genotypeRhizosphere_OTUs_spontaneum_sum_reads_tax_ordered[,7] == "c__Alphaproteobacteria", "deepskyblue", 
                                       (ifelse(genotypeRhizosphere_OTUs_spontaneum_sum_reads_tax_ordered[,7] == "c__Betaproteobacteria", "darkorange", 
                                               (ifelse(genotypeRhizosphere_OTUs_spontaneum_sum_reads_tax_ordered[,7] == "c__Gammaproteobacteria", "forestgreen",
                                                       (ifelse(genotypeRhizosphere_OTUs_spontaneum_sum_reads_tax_ordered[,7] == "c__Flavobacteriia", "blueviolet", "black")))))))))        

#Landrace
#Root_OTUs_landrace
dat_class_Root_landrace <- as.matrix(dat_tax2[Root_landrace_OTUs_correct, 2])
rownames(dat_class_Root_landrace) <- Root_landrace_OTUs_correct
genotypeRoot_OTUs_landrace_sum_reads_tax <- cbind(genotypeRoot_OTUs_landrace_sum_reads, dat_class_Root_landrace)
genotypeRoot_OTUs_landrace_sum_reads_tax_ordered <- as.matrix(genotypeRoot_OTUs_landrace_sum_reads_tax[order(genotypeRoot_OTUs_landrace_sum_reads_tax[,7]), ])
genotypeRoot_OTUs_landrace_sum_reads_tax_ordered 
genotypeRoot_OTUs_landrace_sum_reads_tax_ordered_count <- genotypeRoot_OTUs_landrace_sum_reads[rownames(genotypeRoot_OTUs_landrace_sum_reads_tax_ordered), ] 
taxa_pie_colors_root_l <- ifelse(genotypeRoot_OTUs_landrace_sum_reads_tax_ordered[,7] == "c__Actinobacteria" , "red", 
                                 (ifelse(genotypeRoot_OTUs_landrace_sum_reads_tax_ordered[,7] == "c__Alphaproteobacteria", "deepskyblue", 
                                         (ifelse(genotypeRoot_OTUs_landrace_sum_reads_tax_ordered[,7] == "c__Betaproteobacteria", "darkorange", 
                                                 (ifelse(genotypeRoot_OTUs_landrace_sum_reads_tax_ordered[,7] == "c__Gammaproteobacteria", "forestgreen",
                                                         (ifelse(genotypeRoot_OTUs_landrace_sum_reads_tax_ordered[,7] == "c__Flavobacteriia", "blueviolet", "black")))))))))        
#RR_OTUs_landrace
dat_class_RR_landrace <- as.matrix(dat_tax2[RR_OTUs_landrace, 2])
rownames(dat_class_RR_landrace) <- RR_OTUs_landrace
genotype_RR_RROTUs_landrace_sum_reads_tax <- cbind(genotype_RR_RROTUs_landrace_sum_reads, dat_class_RR_landrace)
genotype_RR_RROTUs_landrace_sum_reads_tax_ordered <- as.matrix(genotype_RR_RROTUs_landrace_sum_reads_tax[order(genotype_RR_RROTUs_landrace_sum_reads_tax[,13]), ])
genotype_RR_RROTUs_landrace_sum_reads_tax_ordered
genotype_RR_RROTUs_landrace_sum_reads_tax_ordered_count <- genotype_RR_RROTUs_landrace_sum_reads[rownames(genotype_RR_RROTUs_landrace_sum_reads_tax_ordered), ] 
taxa_pie_colors_RR_l <- ifelse(genotype_RR_RROTUs_landrace_sum_reads_tax_ordered[,13] == "c__Actinobacteria" , "red", 
                                   (ifelse(genotype_RR_RROTUs_landrace_sum_reads_tax_ordered[,13] == "c__Alphaproteobacteria", "deepskyblue", 
                                           (ifelse(genotype_RR_RROTUs_landrace_sum_reads_tax_ordered[,13] == "c__Betaproteobacteria", "darkorange", 
                                                   (ifelse(genotype_RR_RROTUs_landrace_sum_reads_tax_ordered[,13] == "c__Gammaproteobacteria", "forestgreen",
                                                           (ifelse(genotype_RR_RROTUs_landrace_sum_reads_tax_ordered[,13] == "c__Flavobacteriia", "blueviolet", "black")))))))))        
#Rhizo_OTUs_landrace
dat_class_rhizo_landrace <- as.matrix(dat_tax2[Rhizo_landrace_OTUs_correct, 2])
rownames(dat_class_rhizo_landrace) <- Rhizo_landrace_OTUs_correct
genotypeRhizosphere_OTUs_landrace_sum_reads_tax <- cbind(genotypeRhizosphere_OTUs_landrace_sum_reads, dat_class_rhizo_landrace)
genotypeRhizosphere_OTUs_landrace_sum_reads_tax_ordered <- as.matrix(genotypeRhizosphere_OTUs_landrace_sum_reads_tax[order(genotypeRhizosphere_OTUs_landrace_sum_reads_tax[,7]), ])
genotypeRhizosphere_OTUs_landrace_sum_reads_tax_ordered
genotypeRhizosphere_OTUs_landrace_sum_reads_tax_ordered_count <- genotypeRhizosphere_OTUs_landrace_sum_reads[rownames(genotypeRhizosphere_OTUs_landrace_sum_reads_tax_ordered), ] 
taxa_pie_colors_rhizo_l <- ifelse(genotypeRhizosphere_OTUs_landrace_sum_reads_tax_ordered[,7] == "c__Actinobacteria" , "red", 
                                  (ifelse(genotypeRhizosphere_OTUs_landrace_sum_reads_tax_ordered[,7] == "c__Alphaproteobacteria", "deepskyblue", 
                                          (ifelse(genotypeRhizosphere_OTUs_landrace_sum_reads_tax_ordered[,7] == "c__Betaproteobacteria", "darkorange", 
                                                  (ifelse(genotypeRhizosphere_OTUs_landrace_sum_reads_tax_ordered[,7] == "c__Gammaproteobacteria", "forestgreen",
                                                          (ifelse(genotypeRhizosphere_OTUs_landrace_sum_reads_tax_ordered[,7] == "c__Flavobacteriia", "blueviolet", "black")))))))))        

#Modern
#Root_OTUs_modern
dat_class_Root_modern <- as.matrix(dat_tax2[Root_modern_OTUs_correct, 2])
rownames(dat_class_Root_modern) <- Root_modern_OTUs_correct
genotypeRoot_OTUs_modern_sum_reads_tax <- cbind(genotypeRoot_OTUs_modern_sum_reads, dat_class_Root_modern)
genotypeRoot_OTUs_modern_sum_reads_tax_ordered <- as.matrix(genotypeRoot_OTUs_modern_sum_reads_tax[order(genotypeRoot_OTUs_modern_sum_reads_tax[,7]), ])
genotypeRoot_OTUs_modern_sum_reads_tax_ordered 
genotypeRoot_OTUs_modern_sum_reads_tax_ordered_count <- genotypeRoot_OTUs_modern_sum_reads[rownames(genotypeRoot_OTUs_modern_sum_reads_tax_ordered), ] 
taxa_pie_colors_root_m<- ifelse(genotypeRoot_OTUs_modern_sum_reads_tax_ordered[,7] == "c__Actinobacteria" , "red", 
                                 (ifelse(genotypeRoot_OTUs_modern_sum_reads_tax_ordered[,7] == "c__Alphaproteobacteria", "deepskyblue", 
                                         (ifelse(genotypeRoot_OTUs_modern_sum_reads_tax_ordered[,7] == "c__Betaproteobacteria", "darkorange", 
                                                 (ifelse(genotypeRoot_OTUs_modern_sum_reads_tax_ordered[,7] == "c__Gammaproteobacteria", "forestgreen",
                                                         (ifelse(genotypeRoot_OTUs_modern_sum_reads_tax_ordered[,7] == "c__Flavobacteriia", "blueviolet", "black")))))))))        
#RR_OTUs_modern
dat_class_RR_modern <- as.matrix(dat_tax2[RR_OTUs_modern, 2])
rownames(dat_class_RR_modern) <- RR_OTUs_modern
genotype_RR_RROTUs_modern_sum_reads_tax <- cbind(genotype_RR_RROTUs_modern_sum_reads, dat_class_RR_modern)
genotype_RR_RROTUs_modern_sum_reads_tax_ordered <- as.matrix(genotype_RR_RROTUs_modern_sum_reads_tax[order(genotype_RR_RROTUs_modern_sum_reads_tax[,13]), ])
genotype_RR_RROTUs_modern_sum_reads_tax_ordered
genotype_RR_RROTUs_modern_sum_reads_tax_ordered_count <- genotype_RR_RROTUs_modern_sum_reads[rownames(genotype_RR_RROTUs_modern_sum_reads_tax_ordered), ] 
taxa_pie_colors_RR_m <- ifelse(genotype_RR_RROTUs_modern_sum_reads_tax_ordered[,13] == "c__Actinobacteria" , "red", 
                                   (ifelse(genotype_RR_RROTUs_modern_sum_reads_tax_ordered[,13] == "c__Alphaproteobacteria", "deepskyblue", 
                                           (ifelse(genotype_RR_RROTUs_modern_sum_reads_tax_ordered[,13] == "c__Betaproteobacteria", "darkorange", 
                                                   (ifelse(genotype_RR_RROTUs_modern_sum_reads_tax_ordered[,13] == "c__Gammaproteobacteria", "forestgreen",
                                                           (ifelse(genotype_RR_RROTUs_modern_sum_reads_tax_ordered[,13] == "c__Flavobacteriia", "blueviolet", "black")))))))))        
#Rhizo_OTUs_modern
dat_class_rhizo_modern <- as.matrix(dat_tax2[Rhizo_modern_OTUs_correct, 2])
rownames(dat_class_rhizo_modern) <- Rhizo_modern_OTUs_correct
genotypeRhizosphere_OTUs_modern_sum_reads_tax <- cbind(genotypeRhizosphere_OTUs_modern_sum_reads, dat_class_rhizo_modern)
genotypeRhizosphere_OTUs_modern_sum_reads_tax_ordered <- as.matrix(genotypeRhizosphere_OTUs_modern_sum_reads_tax[order(genotypeRhizosphere_OTUs_modern_sum_reads_tax[,7]), ])
genotypeRhizosphere_OTUs_modern_sum_reads_tax_ordered
genotypeRhizosphere_OTUs_modern_sum_reads_tax_ordered_count <- genotypeRhizosphere_OTUs_modern_sum_reads[rownames(genotypeRhizosphere_OTUs_modern_sum_reads_tax_ordered), ] 
taxa_pie_colors_rhizo_m <- ifelse(genotypeRhizosphere_OTUs_modern_sum_reads_tax_ordered[,7] == "c__Actinobacteria" , "red", 
                                  (ifelse(genotypeRhizosphere_OTUs_modern_sum_reads_tax_ordered[,7] == "c__Alphaproteobacteria", "deepskyblue", 
                                          (ifelse(genotypeRhizosphere_OTUs_modern_sum_reads_tax_ordered[,7] == "c__Betaproteobacteria", "darkorange", 
                                                  (ifelse(genotypeRhizosphere_OTUs_modern_sum_reads_tax_ordered[,7] == "c__Gammaproteobacteria", "forestgreen",
                                                          (ifelse(genotypeRhizosphere_OTUs_modern_sum_reads_tax_ordered[,7] == "c__Flavobacteriia", "blueviolet", "black")))))))))        


#plotting
dev.off()
par(mfrow=c(3,3))
pie(rowSums(genotypeRoot_OTUs_spontaneum_sum_reads_tax_ordered_count), col=taxa_pie_colors_root_s, clockwise=TRUE)
pie(rowSums(genotype_RR_RROTUs_spontaneum_sum_reads_tax_ordered_count), col=taxa_pie_colors_RR_s, clockwise=TRUE)
pie(rowSums(genotypeRhizosphere_OTUs_spontaneum_sum_reads_tax_ordered_count), col=taxa_pie_colors_rhizo_s, clockwise=TRUE)
pie(rowSums(genotypeRoot_OTUs_landrace_sum_reads_tax_ordered_count), col=taxa_pie_colors_root_l, clockwise=TRUE)
pie(rowSums(genotype_RR_RROTUs_landrace_sum_reads_tax_ordered_count), col=taxa_pie_colors_RR_l, clockwise=TRUE)
pie(rowSums(genotypeRhizosphere_OTUs_landrace_sum_reads_tax_ordered_count), col=taxa_pie_colors_rhizo_l, clockwise=TRUE)
pie(rowSums(genotypeRoot_OTUs_modern_sum_reads_tax_ordered_count), col=taxa_pie_colors_root_m, clockwise=TRUE)
pie(rowSums(genotype_RR_RROTUs_modern_sum_reads_tax_ordered_count), col=taxa_pie_colors_RR_m, clockwise=TRUE)
pie(rowSums(genotypeRhizosphere_OTUs_modern_sum_reads_tax_ordered_count), col=taxa_pie_colors_rhizo_m, clockwise=TRUE)

#subfigures of ternary plots and pie charts saved as .eps files and combined in Adobe Illustrator. For graphical representation OTU iD removed from the pie charts.


####################################
#Genotype effect corrected for Microhabitat  and Experiment
####################################

#define the factor Accessiion corrected for Experiment and Microhabitat
genotype <- as.vector(paste(design$Microhabitat, design$Experiment, design$Accession, sep="."))
model_genotype <- model.matrix(~0 + genotype)
colnames(model_genotype) <- make.names(colnames(model_genotype))
colnames(model_genotype)
#fit the linear model
fit_genotype <- lmFit(eset, model_genotype)
#Genotype effect Rhizosphere 1193R
cont.matrix_genotype <- makeContrasts(
  M_vs_L_3 = genotypeRhizosphere.Barley3.modern - genotypeRhizosphere.Barley3.landrace,
  M_vs_L_2 = genotypeRhizosphere.Barley2.modern - genotypeRhizosphere.Barley2.landrace,
  M_vs_S_3 = genotypeRhizosphere.Barley3.modern - genotypeRhizosphere.Barley3.spontaneum,
  M_vs_S_2 = genotypeRhizosphere.Barley2.modern - genotypeRhizosphere.Barley2.spontaneum,
  S_vs_L_3 = genotypeRhizosphere.Barley3.spontaneum - genotypeRhizosphere.Barley3.landrace,
  S_vs_L_2 = genotypeRhizosphere.Barley2.spontaneum - genotypeRhizosphere.Barley2.landrace,
  levels = model_genotype)
# Compute estimated coefficients and standard errors for the given contrasts
fit2_genotype <- contrasts.fit(fit_genotype, cont.matrix_genotype)
fit2_genotype <- eBayes(fit2_genotype)
#decideTests: by default lfc>0, BH corrected
de_tab_genotype <- decideTests(fit2_genotype)
#identify relevant OTUs
M_vs_L_3_OTUs_1193_Rhizo <- rownames(de_tab_genotype)[de_tab_genotype[,1] ==1]
L_vs_M_3_OTUs_1193_Rhizo <- rownames(de_tab_genotype)[de_tab_genotype[,1] == -1]
M_vs_L_2_OTUs_1193_Rhizo <- rownames(de_tab_genotype)[de_tab_genotype[,2] ==1]
L_vs_M_2_OTUs_1193_Rhizo <- rownames(de_tab_genotype)[de_tab_genotype[,2] == -1]
M_vs_S_3_OTUs_1193_Rhizo <- rownames(de_tab_genotype)[de_tab_genotype[,3] ==1]
S_vs_M_3_OTUs_1193_Rhizo <- rownames(de_tab_genotype)[de_tab_genotype[,3] == -1]
M_vs_S_2_OTUs_1193_Rhizo <- rownames(de_tab_genotype)[de_tab_genotype[,4] ==1]
S_vs_M_2_OTUs_1193_Rhizo <- rownames(de_tab_genotype)[de_tab_genotype[,4] == -1]
S_vs_L_3_OTUs_1193_Rhizo <- rownames(de_tab_genotype)[de_tab_genotype[,5] == 1]
L_vs_S_3_OTUs_1193_Rhizo <- rownames(de_tab_genotype)[de_tab_genotype[,5] == -1]
S_vs_L_2_OTUs_1193_Rhizo <- rownames(de_tab_genotype)[de_tab_genotype[,6] == 1]
L_vs_S_2_OTUs_1193_Rhizo <- rownames(de_tab_genotype)[de_tab_genotype[,6] == -1]
length(M_vs_L_3_OTUs_1193_Rhizo)
length(L_vs_M_3_OTUs_1193_Rhizo)
length(M_vs_L_2_OTUs_1193_Rhizo)
length(L_vs_M_2_OTUs_1193_Rhizo)
length(M_vs_S_3_OTUs_1193_Rhizo)
length(S_vs_M_3_OTUs_1193_Rhizo)
length(M_vs_S_2_OTUs_1193_Rhizo)
length(S_vs_M_2_OTUs_1193_Rhizo)
length(L_vs_S_3_OTUs_1193_Rhizo)
length(L_vs_S_2_OTUs_1193_Rhizo)
length(S_vs_L_3_OTUs_1193_Rhizo)
length(S_vs_L_2_OTUs_1193_Rhizo)
M_vs_L_Rhizo_OTUs_1193 <- intersect (M_vs_L_3_OTUs_1193_Rhizo, M_vs_L_2_OTUs_1193_Rhizo)
M_vs_S_Rhizo_OTUs_1193 <- intersect (M_vs_S_3_OTUs_1193_Rhizo, M_vs_S_2_OTUs_1193_Rhizo)
L_vs_M_Rhizo_OTUs_1193 <- intersect (L_vs_M_3_OTUs_1193_Rhizo, L_vs_M_2_OTUs_1193_Rhizo)
L_vs_S_Rhizo_OTUs_1193 <- intersect (L_vs_S_3_OTUs_1193_Rhizo, L_vs_S_2_OTUs_1193_Rhizo)
S_vs_M_Rhizo_OTUs_1193 <- intersect (S_vs_M_3_OTUs_1193_Rhizo, S_vs_M_2_OTUs_1193_Rhizo)
S_vs_L_Rhizo_OTUs_1193 <- intersect (S_vs_L_3_OTUs_1193_Rhizo, S_vs_L_2_OTUs_1193_Rhizo)
length(M_vs_L_Rhizo_OTUs_1193)
length(M_vs_S_Rhizo_OTUs_1193)
length(L_vs_M_Rhizo_OTUs_1193)
length(L_vs_S_Rhizo_OTUs_1193)
length(S_vs_M_Rhizo_OTUs_1193)
length(S_vs_L_Rhizo_OTUs_1193)

#Genotype effect root 
cont.matrix_genotype <- makeContrasts(
  M_vs_L_3 = genotypeRoot.Barley3.modern - genotypeRoot.Barley3.landrace,
  M_vs_L_2 = genotypeRoot.Barley2.modern - genotypeRoot.Barley2.landrace,
  M_vs_S_3 = genotypeRoot.Barley3.modern - genotypeRoot.Barley3.spontaneum,
  M_vs_S_2 = genotypeRoot.Barley2.modern - genotypeRoot.Barley2.spontaneum,
  S_vs_L_3 = genotypeRoot.Barley3.spontaneum - genotypeRoot.Barley3.landrace,
  S_vs_L_2 = genotypeRoot.Barley2.spontaneum - genotypeRoot.Barley2.landrace,
  levels = model_genotype)
# Compute estimated coefficients and standard errors for the given contrasts
fit2_genotype <- contrasts.fit(fit_genotype, cont.matrix_genotype)
fit2_genotype <- eBayes(fit2_genotype)
#decideTests: by default lfc>0, BH correct
de_tab_genotype <- decideTests(fit2_genotype)

#identify relevant OTUs
M_vs_L_3_OTUs_1193_Root <- rownames(de_tab_genotype)[de_tab_genotype[,1] ==1]
L_vs_M_3_OTUs_1193_Root <- rownames(de_tab_genotype)[de_tab_genotype[,1] == -1]
M_vs_L_2_OTUs_1193_Root <- rownames(de_tab_genotype)[de_tab_genotype[,2] ==1]
L_vs_M_2_OTUs_1193_Root <- rownames(de_tab_genotype)[de_tab_genotype[,2] == -1]
M_vs_S_3_OTUs_1193_Root <- rownames(de_tab_genotype)[de_tab_genotype[,3] ==1]
S_vs_M_3_OTUs_1193_Root <- rownames(de_tab_genotype)[de_tab_genotype[,3] == -1]
M_vs_S_2_OTUs_1193_Root <- rownames(de_tab_genotype)[de_tab_genotype[,4] ==1]
S_vs_M_2_OTUs_1193_Root <- rownames(de_tab_genotype)[de_tab_genotype[,4] == -1]
S_vs_L_3_OTUs_1193_Root <- rownames(de_tab_genotype)[de_tab_genotype[,5] == 1]
L_vs_S_3_OTUs_1193_Root <- rownames(de_tab_genotype)[de_tab_genotype[,5] == -1]
S_vs_L_2_OTUs_1193_Root <- rownames(de_tab_genotype)[de_tab_genotype[,6] == 1]
L_vs_S_2_OTUs_1193_Root <- rownames(de_tab_genotype)[de_tab_genotype[,6] == -1]
length(M_vs_L_3_OTUs_1193_Root)
length(L_vs_M_3_OTUs_1193_Root)
length(M_vs_L_2_OTUs_1193_Root)
length(L_vs_M_2_OTUs_1193_Root)
length(M_vs_S_3_OTUs_1193_Root)
length(S_vs_M_3_OTUs_1193_Root)
length(M_vs_S_2_OTUs_1193_Root)
length(S_vs_M_2_OTUs_1193_Root)
length(L_vs_S_3_OTUs_1193_Root)
length(L_vs_S_2_OTUs_1193_Root)
M_vs_L_Root_OTUs_1193 <- intersect (M_vs_L_3_OTUs_1193_Root, M_vs_L_2_OTUs_1193_Root)
M_vs_S_Root_OTUs_1193 <- intersect (M_vs_S_3_OTUs_1193_Root, M_vs_S_2_OTUs_1193_Root)
L_vs_M_Root_OTUs_1193 <- intersect (L_vs_M_3_OTUs_1193_Root, L_vs_M_2_OTUs_1193_Root)
L_vs_S_Root_OTUs_1193 <- intersect (L_vs_S_3_OTUs_1193_Root, L_vs_S_2_OTUs_1193_Root)
S_vs_M_Root_OTUs_1193 <- intersect (S_vs_M_3_OTUs_1193_Root, S_vs_M_2_OTUs_1193_Root)
S_vs_L_Root_OTUs_1193 <- intersect (S_vs_L_3_OTUs_1193_Root, S_vs_L_2_OTUs_1193_Root)
length(M_vs_L_Root_OTUs_1193)
length(M_vs_S_Root_OTUs_1193)
length(L_vs_M_Root_OTUs_1193)
length(L_vs_S_Root_OTUs_1193)
length(S_vs_M_Root_OTUs_1193)
length(S_vs_L_Root_OTUs_1193)


###########
#Adonis calculation
###########
#import the distance matrices generated in QIIME 

#Bray-Curtis
dat_count.bc <- read.delim("bray_curtis_dat_info_Barley_OTUPARSE_NM_th.txt", row.names=1, header=T)
dat_count.bc <- as.matrix(dat_count.bc)
#convert as distance matrix vegan compatible (note only squared matrix are allowed)
dat_count_bc.dis <- as.dist(dat_count.bc, diag = FALSE, upper = FALSE)

#unweighted unifrac
dat_count.uu <- read.delim("unweighted_unifrac_dat_info_Barley_OTUPARSE_NM_th.txt", row.names=1, header=T)
dat_count.uu <- as.matrix(dat_count.uu)
#convert as distance matrix vegan compatible (note only squared matrix are allowed)
dat_count_uu.dis <- as.dist(dat_count.uu, diag = FALSE, upper = FALSE)

#unweighted unifrac
dat_count.wu <- read.delim("weighted_unifrac_dat_info_Barley_OTUPARSE_NM_th.txt", row.names=1, header=T)
dat_count.wu <- as.matrix(dat_count.wu)
#convert as distance matrix vegan compatible (note only squared matrix are allowed)
dat_count_wu.dis <- as.dist(dat_count.wu, diag = FALSE, upper = FALSE)



#Microhabitat Using Permutational Analysis of Variance

#adonis bc
adonis(dat_count_bc.dis~Microhabitat, data=design, permutations = 5000)
#adonis uu
adonis(dat_count_uu.dis~Microhabitat, data=design, permutations = 5000)
#adonis wu
adonis(dat_count_wu.dis~Microhabitat, data=design, permutations = 5000)


#Permutational Analysis of Variance on plant-associated microhabitats corrected for experiment

#preprocessing of the data
#Rhizosphere samples  (second column of the table)
dat_count.uu_rhizosphere <- dat_count.uu[rownames(design)[which(design$Microhabitat == "Rhizosphere")], rownames(design)[which(design$Microhabitat == "Rhizosphere")]] 
dat_count.wu_rhizosphere <- dat_count.wu[rownames(design)[which(design$Microhabitat == "Rhizosphere")], rownames(design)[which(design$Microhabitat == "Rhizosphere")]] 
dat_count.bc_rhizosphere <- dat_count.bc[rownames(design)[which(design$Microhabitat == "Rhizosphere")], rownames(design)[which(design$Microhabitat == "Rhizosphere")]] 

#unweighted unifrac
dat_count.uu_rhizosphere <- as.matrix(dat_count.uu_rhizosphere)
#convert as distance matrix vegan compatible (note only squared matrix are allowed)
dat_count_uu_rhizosphere.dis <- as.dist(dat_count.uu_rhizosphere, diag = FALSE, upper = FALSE)

#weighted unifrac
dat_count.wu_rhizosphere <- as.matrix(dat_count.wu_rhizosphere)
#convert as distance matrix vegan compatible (note only squared matrix are allowed)
dat_count_wu_rhizosphere.dis <- as.dist(dat_count.wu_rhizosphere, diag = FALSE, upper = FALSE)

#Bray-Curtis
dat_count.bc_rhizosphere <- as.matrix(dat_count.bc_rhizosphere)
#convert as distance matrix vegan compatible (note only squared matrix are allowed)
dat_count_bc_rhizosphere.dis <- as.dist(dat_count.bc_rhizosphere, diag = FALSE, upper = FALSE)

#subset the design file for rhizosphere samples
design_rhizosphere <- design[which(design$Microhabitat == "Rhizosphere"), ]

#adonis uu rhizosphere
adonis(dat_count_uu_rhizosphere.dis~Accession*Experiment, data=design_rhizosphere, permutations = 5000)
#adonis wu rhizosphere
adonis(dat_count_wu_rhizosphere.dis~Accession*Experiment, data=design_rhizosphere, permutations = 5000)
#adonis bc rhizosphere
adonis(dat_count_bc_rhizosphere.dis~Accession*Experiment, data=design_rhizosphere, permutations = 5000)


#Root samples (third column of the table)
dat_count.uu_root <- dat_count.uu[rownames(design)[which(design$Microhabitat == "Root")], rownames(design)[which(design$Microhabitat == "Root")]] 
dat_count.wu_root <- dat_count.wu[rownames(design)[which(design$Microhabitat == "Root")], rownames(design)[which(design$Microhabitat == "Root")]] 
dat_count.bc_root <- dat_count.bc[rownames(design)[which(design$Microhabitat == "Root")], rownames(design)[which(design$Microhabitat == "Root")]] 

#unweighted unifrac
dat_count.uu_root <- as.matrix(dat_count.uu_root)
#convert as distance matrix vegan compatible (note only squared matrix are allowed)
dat_count_uu_root.dis <- as.dist(dat_count.uu_root, diag = FALSE, upper = FALSE)

#weighted unifrac
dat_count.wu_root <- as.matrix(dat_count.wu_root)
#convert as distance matrix vegan compatible (note only squared matrix are allowed)
dat_count_wu_root.dis <- as.dist(dat_count.wu_root, diag = FALSE, upper = FALSE)

#Bray-Curtis
dat_count.bc_root <- as.matrix(dat_count.bc_root)
#convert as distance matrix vegan compatible (note only squared matrix are allowed)
dat_count_bc_root.dis <- as.dist(dat_count.bc_root, diag = FALSE, upper = FALSE)

#subset the design file for root samples
design_root <- design[which(design$Microhabitat == "Root"), ]

#adonis uu root
adonis(dat_count_uu_root.dis~Accession*Experiment, data=design_root, permutations = 5000)
#adonis wu root
adonis(dat_count_wu_root.dis~Accession*Experiment, data=design_root, permutations = 5000)
#adonis bc root
adonis(dat_count_bc_root.dis~Accession*Experiment, data=design_root, permutations = 5000)


#########################################
#Figure 4: Identify At root enriched OTUs
#########################################


#upload the dataset with the OTU count per sample and the taxonomy information At dataset
dat_count_At_Golm_OTUPARSE <- read.delim("Libs_At_Golm_UPARSE_OTU_count.txt", row.names= 1,  header=T, sep="\t")
colnames(dat_count_At_Golm_OTUPARSE)
dim(dat_count_At_Golm_OTUPARSE)
sort(colSums(dat_count_At_Golm_OTUPARSE))

#upload the taxonmy information
dat_taxa_At_Golm_OTUPARSE <- read.delim("Libs_At_Golm_HQ_UPARSE_otus_NC_ID_tax_assignments.txt", row.names= 1, sep="\t")
dim(dat_taxa_At_Golm_OTUPARSE)
colnames(dat_taxa_At_Golm_OTUPARSE) <- c("taxonomy", "confidence")
colnames(dat_taxa_At_Golm_OTUPARSE)
dat_taxa_At_Golm_OTUPARSE <- dat_taxa_At_Golm_OTUPARSE[rownames(dat_count_At_Golm_OTUPARSE), ]

#combine the databases
dat_info_At_Golm_OTUPARSE <- cbind(dat_count_At_Golm_OTUPARSE, dat_taxa_At_Golm_OTUPARSE)
dim(dat_info_At_Golm_OTUPARSE)
colnames(dat_info_At_Golm_OTUPARSE)
dat_info_At_Golm_OTUPARSE$taxonomy

#Identify and deplente OTUs assigned to Chloroflexi
Chloroflexi_OTUs<- dat_info_At_Golm_OTUPARSE[grep("p__Chloroflexi", dat_info_At_Golm_OTUPARSE$taxonomy), ]
dim(Chloroflexi_OTUs)
dat_info_At_Golm_OTUPARSE_noChloroflexi <- dat_info_At_Golm_OTUPARSE[(setdiff(rownames(dat_info_At_Golm_OTUPARSE), rownames(Chloroflexi_OTUs))), ]
dim(dat_info_At_Golm_OTUPARSE_noChloroflexi)
check_tax <- dat_info_At_Golm_OTUPARSE_noChloroflexi[grep("p__Chloroflexi", dat_info_At_Golm_OTUPARSE_noChloroflexi$taxonomy), ]
sort(colSums(dat_info_At_Golm_OTUPARSE_noChloroflexi[, 1:38]))
dat_count_At_Golm_OTUPARSE <- dat_info_At_Golm_OTUPARSE_noChloroflexi[, 1:38] 

#identify and deplete samples with <1000 reads
Sample_above1000 <-colnames(dat_count_At_Golm_OTUPARSE)[which(colSums(dat_count_At_Golm_OTUPARSE ) > 1000)]
dat_count_At_Golm_OTUPARSE_1000 <- dat_count_At_Golm_OTUPARSE[ ,Sample_above1000]
sort(colSums(dat_count_At_Golm_OTUPARSE_1000))
dim(dat_count_At_Golm_OTUPARSE_1000)


# upload the design file
design_At <- read.delim("Libs_At_Golm_UPARSE_design.txt", sep = "\t", header=TRUE, row.names=1)
rownames(design_At) <- design[,1]
dim(design_At)
design_At

# threshold
threshold <- 5

# normalization by sample size and transformation in "/1000"
dat_norm_At <- t(t(dat_count_At_Golm_OTUPARSE_1000/colSums(dat_count_At_Golm_OTUPARSE_1000,na=T)) * 1000)

#application of threshold for lower presence limit of relative abundance
dat_thres_At <- dat_norm_At[ apply(dat_norm_At,1,max) > threshold, ]

#log2-transformation
dat_log_At <- log2(dat_thres_At + 1)
dim(dat_log_At)

#check the order name
design_At <- design_At[colnames(dat_log_At), ]
rownames(design_At)
colnames(dat_log_At)

eset <- new("ExpressionSet")
exprs(eset) <- dat_log_At
pData(eset) <- design_At

#define the factor Microhabitat corrected for Accession
genotype <- as.vector(paste(design_At$Microhabitat, design_At$Genotype, sep="."))
model_genotype <- model.matrix(~0 + genotype)
colnames(model_genotype) <- make.names(colnames(model_genotype))
colnames(model_genotype)
#fit the linear model
fit_genotype <- lmFit(eset, model_genotype)
#Microhabitat * Accession effect
cont.matrix_genotype <- makeContrasts(
  Soil_vs_RootLer = genotypeSoil.Golm -genotypeRoot.Ler,
  Soil_vs_RhizosphereLer = genotypeSoil.Golm - genotypeRhizosphere.Ler,
  Soil_vs_RootSha = genotypeSoil.Golm -genotypeRoot.Sha,
  Soil_vs_RhizosphereSha = genotypeSoil.Golm - genotypeRhizosphere.Sha,  
  levels = model_genotype)
# Compute estimated coefficients and standard errors for the given contrasts
fit2_genotype <- contrasts.fit(fit_genotype, cont.matrix_genotype)
fit2_genotype <- eBayes(fit2_genotype)
#decideTests: by default lfc>0, BH correct
de_tab_genotype <- decideTests(fit2_genotype)

#Root effect: enriched from soil
Root_At_OTUs_Ler <- rownames(de_tab_genotype)[de_tab_genotype[,1] ==-1]
Root_At_OTUs_Sha <- rownames(de_tab_genotype)[de_tab_genotype[,3] ==-1]
length(Root_At_OTUs_Ler)
length(Root_At_OTUs_Sha)
Root_At_OTUs_Golm <- intersect(Root_At_OTUs_Ler, Root_At_OTUs_Sha)

#generate a OTU tables compatible with QIIME for subsetting of representative sequences of Root enriched OTUs
dat_info_Root_At_OTUs_Golm_UPARSE <- dat_info_At_Golm_OTUPARSE[Root_At_OTUs_Golm, 1:39]

stat_Root_At_OTUs_Golm <- median(colSums(dat_info_Root_At_OTUs_Golm_UPARSE[, rownames(design_At)[which(design_At$Microhabitat =="Root")]]))/median(colSums(dat_count_At_Golm_OTUPARSE_1000[, rownames(design_At)[which(design_At$Microhabitat =="Root")]]))

#Figure 4 completed by Ruben Garrido-Oter MPI Cologne

######
#END
#####
