#############################################################
#
# Ref to the ARTICLE
# 
# Davide Bulgarelli
# d.bulgarelli@dundee.ac.uk
# 01/12/2014
# script to generate OTU tables qiime-compatible using OTUPARSE output files and deplete OTU assigned to mitochondria 
# files needed are included in the folder "Bulgarelli_et_al_R_figures_1-3-4-S1_R_scripts. 
#
#############################################################

rm(list=ls())

#set working directory
setwd("C:/Users/DB42008/ownCloud/Manuscripts/Barley_Microbiota_revisionCHM0814_scripts/Bulgarelli_et_al_figures_1-3-4-S1_R_scripts")


# upload the design file
design <- read.delim("371A_530A_design.txt", sep = "\t", header=TRUE )
rownames(design) <- design[,1]
dim(design)
design

#upload the dataset with the OTU count per sample and the taxonomy information
dat_count_Barley_OTUPARSE <- read.delim("371A_530A_UPARSE_OTU_count.txt", row.names= 1,  header=T, sep="\t")
colnames(dat_count_Barley_OTUPARSE)
dim(dat_count_Barley_OTUPARSE)
sort(colSums(dat_count_Barley_OTUPARSE))

#upload the taxonmy information
dat_taxa_Barley_OTUPARSE <- read.delim("371A_530A_UPARSE_otus_NC_ID_tax_assignments_QIIME_compatible.txt", row.names= 1, sep="\t",  header=T)
dim(dat_taxa_Barley_OTUPARSE)
dat_taxa_Barley_OTUPARSE <- dat_taxa_Barley_OTUPARSE[rownames(dat_count_Barley_OTUPARSE), ]

#combine the databases
dat_info_Barley_OTUPARSE <- cbind(dat_count_Barley_OTUPARSE, dat_taxa_Barley_OTUPARSE)
dim(dat_info_Barley_OTUPARSE)
colnames(dat_info_Barley_OTUPARSE)

#Identify and deplente OTUs assigned to Mitochondria
noMitochondria <- rownames(dat_info_Barley_OTUPARSE)[which(dat_info_Barley_OTUPARSE$taxonomy!= "k__Bacteria;p__Proteobacteria;c__Alphaproteobacteria;o__Rickettsiales;f__mitochondria;g__;s__")]
length(noMitochondria)
dat_info_Barley_OTUPARSE_NM <- dat_info_Barley_OTUPARSE[noMitochondria, ] 
dim(dat_info_Barley_OTUPARSE_NM)
sort(colSums(dat_info_Barley_OTUPARSE_NM[, 1:42]))

#generate non-thresholded and thresholded OTU tables compatible with QIIME for construction of taxonomy tables, alpha and betadiversity calculations
#non threshold
dat_info_Barley_OTUPARSE_NM_QIIME <- dat_info_Barley_OTUPARSE_NM[, 1:43]
#this table has been converted in .biom format and used in QIIME. Note: change row lables as "OTU ID#"; add a space after the semicolumn in the taxonomy description prior QIIME importing and then saved as _QIIME_ready.txt
#write.table(dat_info_Barley_OTUPARSE_NM_QIIME , file="dat_info_Barley_OTUPARSE_NM_QIIME.txt", sep="\t")


# threshold
threshold <- 5

#extract the count data from the generated OTU table
dat_count_Barley_OTUPARSE_NM <- dat_info_Barley_OTUPARSE_NM_QIIME[, 1:42]

# normalization by sample size and transformation in "/1000"
dat_norm <- t(t(dat_count_Barley_OTUPARSE_NM/colSums(dat_count_Barley_OTUPARSE_NM,na=T)) * 1000)

#application of threshold for lower presence limit of relative abundance
dat_thres <- dat_norm[ apply(dat_norm,1,max) > threshold, ]

#log2-transformation
dat_log <- log2(dat_thres + 1)
dim(dat_log)

#retrieve the taxonomy assignments of the threshold OTUs
dat_tax_th <- dat_taxa_Barley_OTUPARSE[rownames(dat_log), ]
class(dat_tax_th)
dat_info_th_log <- cbind(dat_log, dat_tax_th)
dim(dat_info_th_log)

#generate the new OTU table
dat_info_Barley_OTUPARSE_NM_logth05_QIIME <- dat_info_th_log[, 1:43]
#this table has been converted in .biom format and used in QIIME. Note: change row lables as "OTU ID#" prior QIIME importing then saved as _QIIME_ready.txt
#write.table(dat_info_Barley_OTUPARSE_NM_logth05_QIIME , file="dat_info_Barley_OTUPARSE_NM_logth05_QIIME.txt", sep="\t")

#############################################################
#END
#############################################################
